//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ADC.h"
#include "stdio.h"
//===============================================================================
//*********************************ADC初始化*************************************
//ADC初始化：选择通道15(IOB7)输入模式模拟端口、关闭上下拉,数据格式为右对齐,
//时钟源选择为Fcpu,参考电压设置内部参考2V
//===============================================================================
void ADC_INIT(void)
{	
	/*ADC通道IO设置,选择通道15(IOB7)输入模式模拟端口*/
	ADCSetADC_IO(ADC_CHANNEL_15);
	/*ADC数据格式选择,数据格式为右对齐*/
    ADCSetADFM(ADC_ADFM_Right);
	/*ADC设置时钟,时钟源选择为16M/Fcpu/16T*/
    ADCSetClk(ADC_CLOCK_FCPU_DIV_1);
    /*ADC设置参考电压,内部参考2V*/
    ADCSetVREMS(ADC_VREMS_IN , ADC_VREF_IN_2V , ADC_VREVH0);
	/* 使能ADC */
	ADEN = ENABLE;
	/*ADC失调校准补偿*/
	ADCSetADVOS();
}
//===============================================================================
//*******************************ADC选择通道设置函数*****************************
//ADC选择通道IO设置
//输入		adcChannel						//通道选择参数
//===============================================================================
void ADCSetADC_IO(enum ADC_CHANNEL adcChannel)
{
	u8 ADC_IOData;
	ADC_IOData = adcChannel & 0x07;
	ADC_IOData = (unsigned char)(0x01 << ADC_IOData);
	if(adcChannel < ADC_CHANNEL_8)
	{
		OEA &= (unsigned char)~ADC_IOData;
		ANSA |= ADC_IOData;
	}
	else if(adcChannel < ADC_CHANNEL_16)
	{
		OEB &= (unsigned char)~ADC_IOData;
		ANSB |= ADC_IOData;
	}
	else if(adcChannel < ADC_CHANNEL_24)
	{
		OEC &= (unsigned char)~ADC_IOData;
		ANSC |= ADC_IOData;
	}
	else if(adcChannel < ADC_CHANNEL_26)
	{
		OED &= (unsigned char)~ADC_IOData;
		ANSD |= ADC_IOData;
	}
	ADCON0 &= ~(0x1F << 0);		
    ADCON0 |= adcChannel;
}
//===============================================================================
//*******************************ADC数据格式设置函数*****************************
//ADC数据格式设置
//输入		adcAdfm						//ADC数据格式选择参数
//===============================================================================
void ADCSetADFM(enum ADC_ADFM adcAdfm)
{
	ADCON0 &= ~(0x01 << 5);	
    ADCON0 |= adcAdfm;
}
//===============================================================================
//*********************************ADC时钟设置函数*******************************
//ADC时钟设置
//输入		adcClk						//ADC时钟源选择参数
//===============================================================================			
void ADCSetClk(enum ADC_CLOCK adcClk)
{
	ADCON1 &= ~(0x07 << 4);	
    ADCON1 |= adcClk;
}
//===============================================================================
//*****************************ADC参考电压模式设置函数***************************
//ADC参考电压模式设置
//输入		adcVrems					//ADC参考电压模式选择参数
//输入		adcVref						//ADC内建基准电平选择参数
//输入		adcVrevh					//AD参考电压VREF+选择参数	
//===============================================================================	
void ADCSetVREMS(enum ADC_VREMS adcVrems,enum ADC_VREF adcVref,enum ADC_VREVH adcVrevh)
{
	ADCON1 &= ~0x8F;
	ADCON1 |= (adcVrems | adcVref);
	ADCON3 &= ~(0x0F << 4);	
	ADCON3 |= adcVrevh;
}
//===============================================================================
//**********************************ADC延时函数**********************************
//===============================================================================					
void ADC_Delay16us(void)
{
	for(u8 i = 3;i > 0;i--)
	{
	
	}
}
//===============================================================================
//*********************************ADC通道值转换函数*****************************
//ADC通道值转换
//输入		adcChannel						//通道选择参数
//返回通道转换值AD_Data
//===============================================================================			
u16 ADC_CONVERTED(enum ADC_CHANNEL adcChannel)
{
	u16 AD_Data;
	ADCON0 &= ~(0x1F << 0);		
    ADCON0 |= (adcChannel << 0);
	ADC_Delay16us();					//延时时间大于一次转换时间或大于16us
	ADS = 1;
	while(ADS == 1);
	{
		AD_Data = AD;
	}
	return AD_Data;
}
//===============================================================================
//*******************************ADC失调校准补偿函数*****************************
//ADC失调校准补偿
//返回1表示校准成功
//返回0表示校准失败
//===============================================================================	
u8 ADCSetADVOS(void)
{
	u16 R_GND_Data;
	u8 R_ADVOS_Temp;
	u8 R_ADVOS_Temp_Old;
	u8 R_ADVOS_Cnt = 0x00;
	u8 i;
	/* 判断20次查找合适的补偿挡位 */
	for(i = 0;i < 20;i++)
	{
		for(ADCON2 &= ~(0x0F << 0); (ADCON2 & 0x0F) < 16;ADCON2++)
		{
			R_GND_Data = ADC_CONVERTED(ADC_CHANNEL_GND);
			if(R_GND_Data > 0x0000)
			{
				if( (ADCON2 & 0x0F) == 0)
				{
					R_ADVOS_Temp = 0;
				}
				else
				{
					R_ADVOS_Temp = (unsigned char)((ADCON2 & 0x0F) - 1);
				}
				break;						//查找到校准挡位
			}
		}
		if(R_ADVOS_Temp_Old == R_ADVOS_Temp)
		{
			R_ADVOS_Cnt++;
			if(R_ADVOS_Cnt > 2)
			{
				ADCON2 &= ~(0x0F << 0);
				ADCON2 |= R_ADVOS_Temp;
				return 1;					//连续四次得到相同结果校准成功
			}
		}
		else
		{
			R_ADVOS_Temp_Old = R_ADVOS_Temp;
			R_ADVOS_Cnt = 0x00;
		}
	}
	return 0;								//校准失败
}
//===============================================================================
//**********************************求平均函数***********************************
//采集10次AD值，去掉最大值和最小值，对剩下的AD值求平均函数
//输入		adcChannel						//通道选择参数
//注：使用取平均函数格式需使用右对齐
//返回求的均值R_ADC_DATA_Sum
//===============================================================================
u16 ADCDATA_AVERAGE(enum ADC_CHANNEL adcChannel)
{
	u16 R_ADC_Temp;
	u16	R_ADC_DATA_Sum = 0x0000;
	u16	R_ADC_MAX_DATA = 0x0000;
	u16	R_ADC_MIN_DATA = 0x0FFF;
	u8	i;
	for(i = 0;i < 10;i++)
	{
		R_ADC_Temp = ADC_CONVERTED(adcChannel);				
		R_ADC_DATA_Sum = R_ADC_DATA_Sum + R_ADC_Temp;
		if(R_ADC_Temp > R_ADC_MAX_DATA)
		{
			R_ADC_MAX_DATA = R_ADC_Temp;
		}
		if(R_ADC_Temp < R_ADC_MIN_DATA)
		{
			R_ADC_MIN_DATA = R_ADC_Temp;
		}	
	}
	R_ADC_DATA_Sum = R_ADC_DATA_Sum - R_ADC_MAX_DATA - R_ADC_MIN_DATA;
	R_ADC_DATA_Sum = R_ADC_DATA_Sum >> 3; 			//剩下8组数据平均
	return R_ADC_DATA_Sum;	
}
//===============================================================================
//*******************************获取VDD电压函数*********************************
//获取VDD电压（前提是参考电压采用内部参考2V）
//返回求得的电压值R_vdd_Voltage
//===============================================================================	
float GetVDD_Voltage(void)
{
    float R_vdd_Voltage;
    u16 R_ADC_RES;
    R_ADC_RES = ADCDATA_AVERAGE(ADC_CHANNEL_VDD_4);
    R_vdd_Voltage = 4 * 2.0 * R_ADC_RES / 4096.0;
    return R_vdd_Voltage;
}
//===============================================================================
//***********************************ADC处理*************************************
//ADC处理：通过串口打印出芯片供电电压以及经过处理后的ADC通道采集值
//===============================================================================
void ADC_Work(void)
{
	u16 R_ADC_Outcome;
	float vddVol;
	/* 测量vdd电压并串口打印 */
	vddVol = GetVDD_Voltage();
    printf("VDD = %.2fV	", (float)vddVol);
	/* 测量ADC通道并串口打印 */
	R_ADC_Outcome = ADCDATA_AVERAGE(ADC_CHANNEL_15);
	printf("ADC_Result = %d\r\n", (int)R_ADC_Outcome);
}

/*********************************END OF FILE************************************/