//===============================================================================
//===============================================================================
#ifndef __ADC_H__
#define __ADC_H__

#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

#define ENABLE							1
#define DISABLE							0
/*ADC数据格式*/
enum ADC_ADFM
{
	ADC_ADFM_Left = 0x00,// 左对齐
    ADC_ADFM_Right = 0x20,// 右对齐
};
/*ADC选择通道，外部通道26,27引脚图没有*/
enum ADC_CHANNEL//通道0~27
{
    ADC_CHANNEL_0 = 0,
    ADC_CHANNEL_1,
    ADC_CHANNEL_2,
    ADC_CHANNEL_3,
    ADC_CHANNEL_4,
    ADC_CHANNEL_5,
    ADC_CHANNEL_6,
    ADC_CHANNEL_7,
    ADC_CHANNEL_8,
    ADC_CHANNEL_9,
    ADC_CHANNEL_10,
    ADC_CHANNEL_11,
    ADC_CHANNEL_12,
    ADC_CHANNEL_13,
    ADC_CHANNEL_14,
    ADC_CHANNEL_15,
    ADC_CHANNEL_16,
    ADC_CHANNEL_17,
    ADC_CHANNEL_18,
    ADC_CHANNEL_19,
    ADC_CHANNEL_20,
    ADC_CHANNEL_21,
    ADC_CHANNEL_22,
    ADC_CHANNEL_23,
	ADC_CHANNEL_24,
	ADC_CHANNEL_25,
	ADC_CHANNEL_26,
	ADC_CHANNEL_27,
	ADC_CHANNEL_VDD_4,
    ADC_CHANNEL_VREF,
	ADC_CHANNEL_OBLIGATE,
    ADC_CHANNEL_GND,    
};
/*ADC时钟*/
enum ADC_CLOCK
{
	ADC_CLOCK_FCPU_DIV_1 = 0x00,//FCPU/1
    ADC_CLOCK_FCPU_DIV_2 = 0x10,//FCPU/2
    ADC_CLOCK_FCPU_DIV_4 = 0x20,//FCPU/4
    ADC_CLOCK_FCPU_DIV_8 = 0x30,//FCPU/8
    ADC_CLOCK_FCPU_DIV_16 = 0x40,//FCPU/16
    ADC_CLOCK_FCPU_DIV_32 = 0x50,//FCPU/32
    ADC_CLOCK_FCPU_DIV_64_1 = 0x60,//FCPU/64
    ADC_CLOCK_FCPU_DIV_64_2 = 0x70,//FCPU/64
};
/*ADC参考电压模式*/
enum ADC_VREMS
{
    ADC_VREMS_VDD = 0x00,//VDD
	ADC_VREMS_IN = 0x04,//内部参考电压
	ADC_VREMS_OUT = 0x08,//外部参考电压
	ADC_VREMS_IN_OUT = 0x0C,//内部参考与外部参考连接
};
/*ADC内建 VREF 基准电平*/
enum ADC_VREF
{
    ADC_VREF_IN_OFF1 = 0x00,//关闭内部参考
    ADC_VREF_IN_2V = 0x01,//内部2.0V
    ADC_VREF_IN_3V = 0x02,//内部3.0V
    ADC_VREF_IN_4V = 0x03,//内部4.0V
	ADC_VREF_IN_OFF2 = 0x80,//关闭内部参考
    ADC_VREF_VREF1 = 0x81,//VREF+
	ADC_VREF_VREF2 = 0x82,//VREF+
	ADC_VREF_VREF3 = 0x83,//VREF+
};
/*ADC设置AD 参考电压选择*/
enum ADC_VREVH
{
    ADC_VREVH0 = 0x00,	//AD 参考电压挡位
	ADC_VREVH1 = 0x10,
	ADC_VREVH2 = 0x20,
	ADC_VREVH3 = 0x30,
	ADC_VREVH4 = 0x40,
	ADC_VREVH5 = 0x50,
	ADC_VREVH6 = 0x60,
	ADC_VREVH7 = 0x70,
	ADC_VREVH8 = 0x80,
	ADC_VREVH9 = 0x90,
	ADC_VREVH10 = 0xA0,
	ADC_VREVH11 = 0xB0,
	ADC_VREVH12 = 0xC0,
	ADC_VREVH13 = 0xD0,
	ADC_VREVH14 = 0xE0,
	ADC_VREVH15 = 0xF0,	
};
//=================================ADC函数声明===========================================
void SYSTEM_INIT(void);//系统初始化
void Delay_1ms(u16 Delay_Count);//延时
void ADCSetADC_IO(enum ADC_CHANNEL adcChannel);//ADC选择通道IO设置
void ADCSetADFM(enum ADC_ADFM adcAdfm);//ADC数据格式设置
void ADCSetClk(enum ADC_CLOCK adcClk);//ADC设置时钟
void ADCSetVREMS(enum ADC_VREMS adcVrems,enum ADC_VREF adcVref,enum ADC_VREVH adcVrevh);//ADC设置参考电压模式
void ADC_Delay16us(void);//ADC延时16us
u16 ADC_CONVERTED(enum ADC_CHANNEL adcChannel);//ADC通道值转换
u8 ADCSetADVOS(void);//ADC失调校准补偿
u16 ADCDATA_AVERAGE(enum ADC_CHANNEL adcChannel);//采集10次AD值，去掉最大值和最小值，对剩下的AD值求平均函数
float GetVDD_Voltage(void);//获取VDD电压
void ADC_INIT(void);//ADC初始化
void ADC_Work(void);//ADC处理程序

#endif
