//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "CMP.h"
#include "stdio.h"
//===============================================================================
//*********************************CMP初始化*************************************
//CMP初始化:正相信号输入选择1/2VDD,反相信号输入选择VLD,VLD电压选择1.25
//CMPC1设置关闭比较器信号输出、无影响,CMPC2设置下降沿触发、滤波关闭
//===============================================================================
void CMP_INIT(void)
{
	/*CMP比较器输出位设置,CP脚输入电压大于CN脚*/
	CMP_SETCMPOUT(CMP_CMPOUT_MORE);
	/*CMPC1设置,关闭比较器信号输出,无影响*/
	CMP_SETCMPC1(CMP_CMPOEN_OFF , CMP_CMPHIEN_OFF);
	/*CMP VLD电压选择位设置,VLD电压选择1.25*/
	CMP_SETCMPVLD(CMP_CMPVLD_1_25);
	/*CMPC2设置,下降沿触发,滤波关闭*/
	CMP_SETCMPC2(CMP_CINTS_UP , CMP_DEB_0);
	/*CMP使能控制位设置,使能比较器*/
	CMPEN = ENABLE;
}
//===============================================================================
//**************************CMP比较器输出位设置函数******************************
//CMP比较器输出位设置
//输入		cmpCmpout						//CMP比较器输出位选择参数
//===============================================================================
void CMP_SETCMPOUT(enum CMP_CMPOUT cmpCmpout)
{
	CMPC0 &= ~(0x01 << 6);
	CMPC0 |= cmpCmpout;
}
//===============================================================================
//**********************CMP比较器输入信号选择位设置函数**************************
//CMP比较器输入信号选择位以及对应端口设置
//输入		cmpCmpns						//CMP比较器反相输入信号选择参数
//输入		cmpCmpps						//CMP比较器正相输入信号选择参数
//对应端口数字输入口，关闭上下拉
//===============================================================================
void CMP_SETINPUT(enum CMP_CMPNS cmpCmpns,enum CMP_CMPPS cmpCmpps)
{
	/*CN口选择CN0/CN1设置对应的端口为输入模式*/
	if(cmpCmpns < 2)
	{
		OED  &= ~(0X01 << cmpCmpns);
		ANSD &= ~(0X01 << cmpCmpns);
	}
	CMPC0 &= ~(0x07 << 3);
	CMPC0 |= (cmpCmpns << 3);
	
	/*CP口选择CP0/CP1/CP2/CP3设置对应的端口为输入模式*/
	if(cmpCmpps < 4)
	{
		OEA  &= ~(0x01 << (cmpCmpps + 3) );
		ANSA &= ~(0x01 << (cmpCmpps + 3) );
    }
	CMPC0 &= ~(0x07 << 0);
    CMPC0 |= (cmpCmpps << 0);
}
//===============================================================================
//********************CMP比较器输出使能设置,P端信号输入控制**********************
//CMP比较器输出使能设置,P端信号输入控制设置
//输入		cmpCmpoen						//CMP比较器输出使能选择参数
//输入		cmpCmphien						//P端信号输入控制选择参数
//===============================================================================
void CMP_SETCMPC1(enum CMP_CMPOEN cmpCmpoen,enum CMP_CMPHIEN cmpCmphien)
{
	CMPC1 &= ~0xC0;
	CMPC1 |= (cmpCmpoen | cmpCmphien );
}
//===============================================================================
//*************************CMP VLD电压选择位设置函数*****************************
//CMP VLD电压选择位设置
//输入		cmpCmpvld						//CCMP VLD电压选择位选择参数
//===============================================================================
void CMP_SETCMPVLD(enum CMP_CMPVLD cmpCmpvld)
{
	CMPC1 &= ~(0x1F << 0);
	CMPC1 |= cmpCmpvld;
}
//===============================================================================
//*******************************CMPC2设置函数***********************************
//CMPC2设置,比较器中断出发类型选择设置、CMP比较器逻辑输出滤波设置
//输入		cmpCints						//比较器中断出发类型选择参数
//输入		cmpDeb							//CMP比较器逻辑输出滤波选择参数
//===============================================================================
void CMP_SETCMPC2(enum CMP_CINTS cmpCints,enum CMP_DEB cmpDeb)
{
	CMPC2 &= ~0xC7;
	CMPC2 |= (cmpCints | cmpDeb);
}
//===============================================================================
//*******************************VDD电压范围函数*********************************
//获取VDD电压范围,CP口选择VLD,CN口选择1/2VDD
//通过改变CMPC1里VLD的值,打印出VDD的电压范围
//===============================================================================
void GetCmpVDD_Voltage(void)
{
	u8 R_CMP_VLD_Temp = 0;
	u8 R_VLD_Temp_Old = 0;
	u8 R_VLD_Cnt = 0;
	float R_vdd_Vldmin = 0.00;
	float R_vdd_Vldmax = 0.00;
	u8 i;	
	/* 判断20次查找对应的挡位 */
	for(i = 0;i < 20;i++)
	{
		for(CMPC1 &= ~(0x1F << 0);(CMPC1 & 0x1F) <= 0x1F;CMPC1++)
		{
		/*CMP比较器输入信号选择位,反相信号输入选择1/2VDD,正相信号输入选择VLD*/
			CMP_SETINPUT(CMP_CMPNS_1_2VDD,CMP_CMPPS_VLD);
			if(CMPOUT == 1)
			{
				R_CMP_VLD_Temp = (unsigned char)(CMPC1 & 0x1F);
				break;
			}
		}
		if(R_VLD_Temp_Old == R_CMP_VLD_Temp)
		{
			R_VLD_Cnt++;
			if(R_VLD_Cnt > 3)
			{
				R_vdd_Vldmin = (1.25 + 0.05 * (R_CMP_VLD_Temp - 1) ) * 2;
				R_vdd_Vldmax = (1.25 + 0.05  * R_CMP_VLD_Temp) * 2;
			}
		}
		else
		{
			R_VLD_Temp_Old = R_CMP_VLD_Temp;
			R_VLD_Cnt = 0x00;
		}
	}
	if((CMPC1&0X1F) == 0X1F && CMPOUT == 1)							//小于2.5V挡位
	{
		printf("VDD>=%.2fV\r ", (float)R_vdd_Vldmax);
	}
	else if((CMPC1&0X1F) == 0 && CMPOUT == 1)						//大于5.6V挡位
	{
		printf("VDD<=%.2fV\r ", (float)R_vdd_Vldmax);
	}
	else
	{
		printf("%.2fV<=VDD<=%.2fV\r ", (float)R_vdd_Vldmin , (float)R_vdd_Vldmax);		
	}
	
}
//===============================================================================
//***********************************CMP处理*************************************
//CMP处理:通过串口打印VDD的电压判断范围以及CP脚和CN脚的大小比较
//===============================================================================
void CMP_Work(void)
{
	GetCmpVDD_Voltage();											//输入VDD电压判断范围
	/*CMP比较器输入信号选择位,反相信号输入选择CN0,正相信号输入选择CP0*/
	CMP_SETINPUT(CMP_CMPNS_CN0,CMP_CMPPS_CP0);
	if(CMPOUT)
	{
		printf(" Outcome= %s\n","CP0>CN0");							//CP(CP0)脚输入电压大于CN(CN0)脚
	}
	else
	{
		printf(" Outcome= %s\n","CP0<CN0");							//CP(CP0)脚输入电压小于CN(CN0)脚
	}
}


/*********************************END OF FILE************************************/