//===============================================================================
//===============================================================================
#ifndef __CMP_H__
#define __CMP_H__

#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

#define ENABLE							1
#define DISABLE							0
/* CMP比较器输出位设置 */
enum CMP_CMPOUT
{
	CMP_CMPOUT_LESS = 0x00,//CP脚输入电压小于CN脚
	CMP_CMPOUT_MORE = 0x40,//CP脚输入电压大于CN脚
};
/* CMP比较器反相输入信号选择位 */
enum CMP_CMPNS
{
	CMP_CMPNS_CN0 = 0,//反相输入信号CN0
	CMP_CMPNS_CN1,//反相输入信号CN1
	CMP_CMPNS_CN2,//反相输入信号CN2
	CMP_CMPNS_CN3,//反相输入信号CN3
	CMP_CMPNS_1_2VDD,//反相输入信号1/2VDD
	CMP_CMPNS_GND,//反相输入信号GND
	CMP_CMPNS_VLD,//反相输入信号VLD
	CMP_CMPNS_NOP,//未定义
};
/* CMP比较器正相输入信号选择位 */
enum CMP_CMPPS
{
	CMP_CMPPS_CP0 = 0,//正相输入信号CP0
	CMP_CMPPS_CP1,//正相输入信号CP1
	CMP_CMPPS_CP2,//正相输入信号CP2
	CMP_CMPPS_CP3,//正相输入信号CP3
	CMP_CMPPS_1_2VDD,//正相输入信号1/2VDD
	CMP_CMPPS_GND,//正相输入信号GND
	CMP_CMPPS_VLD,//正相输入信号VLD
	CMP_CMPPS_NOP,//未定义
};
/* CMP比较器输出使能 */
enum CMP_CMPOEN
{
	CMP_CMPOEN_OFF = 0x00,//关闭比较器信号输出
	CMP_CMPOEN_ON = 0x80,//比较器信号从端口输出
};
/* P端信号输入控制 */
enum CMP_CMPHIEN
{
	CMP_CMPHIEN_OFF = 0x00,//无影响
	CMP_CMPHIEN_ON = 0x40,//不论CMPPS为何值，CP0导通
};
/* VLD电压选择位 */
enum CMP_CMPVLD
{
	CMP_CMPVLD_1_25 = 0x00,//VLD电压选择1.25
	CMP_CMPVLD_1_30 = 0x01,//VLD电压选择1.30
	CMP_CMPVLD_1_35 = 0x02,//VLD电压选择1.35
	CMP_CMPVLD_1_40 = 0x03,//VLD电压选择1.40
	CMP_CMPVLD_1_45 = 0x04,//VLD电压选择1.45
	CMP_CMPVLD_1_50 = 0x05,//VLD电压选择1.50
	CMP_CMPVLD_1_55 = 0x06,//VLD电压选择1.55
	CMP_CMPVLD_1_60 = 0x07,//VLD电压选择1.60
	CMP_CMPVLD_1_65 = 0x08,//VLD电压选择1.65
	CMP_CMPVLD_1_70 = 0x09,//VLD电压选择1.70
	CMP_CMPVLD_1_75 = 0x0A,//VLD电压选择1.75
	CMP_CMPVLD_1_80 = 0x0B,//VLD电压选择1.80
	CMP_CMPVLD_1_85 = 0x0C,//VLD电压选择1.85
	CMP_CMPVLD_1_90 = 0x0D,//VLD电压选择1.90
	CMP_CMPVLD_1_95 = 0x0E,//VLD电压选择1.95
	CMP_CMPVLD_2_00 = 0x0F,//VLD电压选择2.00
	CMP_CMPVLD_2_05 = 0x10,//VLD电压选择2.05
	CMP_CMPVLD_2_10 = 0x11,//VLD电压选择2.10
	CMP_CMPVLD_2_15 = 0x12,//VLD电压选择2.15
	CMP_CMPVLD_2_20 = 0x13,//VLD电压选择2.20
	CMP_CMPVLD_2_25 = 0x14,//VLD电压选择2.25
	CMP_CMPVLD_2_30 = 0x15,//VLD电压选择2.30
	CMP_CMPVLD_2_35 = 0x16,//VLD电压选择2.35
	CMP_CMPVLD_2_40 = 0x17,//VLD电压选择2.40
	CMP_CMPVLD_2_45 = 0x18,//VLD电压选择2.45
	CMP_CMPVLD_2_50 = 0x19,//VLD电压选择2.50
	CMP_CMPVLD_2_55 = 0x1A,//VLD电压选择2.55
	CMP_CMPVLD_2_60 = 0x1B,//VLD电压选择2.60
	CMP_CMPVLD_2_65 = 0x1C,//VLD电压选择2.65
	CMP_CMPVLD_2_70 = 0x1D,//VLD电压选择2.70
	CMP_CMPVLD_2_75 = 0x1E,//VLD电压选择2.75
	CMP_CMPVLD_2_80 = 0x1F,//VLD电压选择2.80
};
/* CMP比较器中断出发类型选择设置 */
enum CMP_CINTS
{
	CMP_CINTS_UP = 0x00,//下降沿触发
	CMP_CINTS_DOWN = 0x40,//上升沿触发
	CMP_CINTS_SIDE = 0x80,//双边沿触发
	CMP_CINTS_NOP = 0xC0,//无
};
/* CMP比较器逻辑输出滤波设置 */
enum CMP_DEB
{
	CMP_DEB_0 = 0x00,//滤波关闭
	CMP_DEB_4 = 0x01,//滤波设置4
	CMP_DEB_8 = 0x02,//滤波设置8
	CMP_DEB_16 = 0x03,//滤波设置16
	CMP_DEB_32 = 0x04,//滤波设置32
	CMP_DEB_64 = 0x05,//滤波设置64
	CMP_DEB_128 = 0x06,//滤波设置128
	CMP_DEB_256 = 0x07,//滤波设置256
};
//=================================CMP函数声明===========================================
void SYSTEM_INIT(void);//系统初始化
void Delay_1ms(u16 Delay_Count);//延时
void CMP_SETCMPOUT(enum CMP_CMPOUT cmpCmpout);//CMP比较器输出位设置
void CMP_SETINPUT(enum CMP_CMPNS cmpCmpns,enum CMP_CMPPS CMPCmpps);//CMP比较器输入信号选择位设置
void CMP_SETCMPC1(enum CMP_CMPOEN cmpCmpoen,enum CMP_CMPHIEN cmpCmphien);//CMP比较器输出使能设置,P端信号输入控制设置
void CMP_SETCMPVLD(enum CMP_CMPVLD cmpCmpvld);//CMP VLD电压选择位设置
void CMP_SETCMPC2(enum CMP_CINTS cmpCints,enum CMP_DEB cmpDeb);//CMPC2设置，比较器中断出发类型选择设置、CMP比较器逻辑输出滤波设置
void GetCmpVDD_Voltage(void);//VDD电压范围
void CMP_Work(void);//CMP处理程序
void CMP_INIT(void);//CMP初始化

#endif
