//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "IIC_MASTER.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
u8 I2C_MASTER_DATA[15] __at(0x20);				//定义存放主机向从机写的数据的数组及其地址
//===============================================================================
//********************************IIC主机初始化**********************************
//IIC主机初始化：端口复用功能IOB0---SCL,IOB1---SDA,I2C复用口设为上拉、数字口、输出
//时钟速度7.625*FCPU*10-3bit/s,不产生起始信号\不产生停止信号\未产生中断\应答NACK 
//===============================================================================		
void I2C_MASTER_INIT(void)
{
	/*I2C复用口设置,端口复用功能IOB0---SCL,IOB1---SDA,I2C复用口设为上拉、数字口*/
	IIC_M_SETREUSE(IIC_M_MPSCL_IOB0 , IIC_M_MPSDA_IOB1);
	/*I2C控制寄存器配置*/
	/* IIC时钟速度控制位设置,时钟速度7.625*FCPU*10-3bit/s */
	IIC_M_SETCR(IIC_M_CR_7_625);
	/* IIC模块使能位设置,使能 */
	I2CEN = ENABLE;
	/* IICCR设置，不产生起始信号\不产生停止信号\未产生中断\应答NACK */
	IIC_M_SETIICCCR(IIC_M_ST_DISABLE , IIC_M_STO_DISABLE , IIC_M_SI_DISABLE , IIC_M_AA_DISABLE);
}
//===============================================================================
//******************************IIC主机复用口设置函数****************************
//IIC主机复用口设置
//输入		iicMmpscl							//主机SCL复用口选择参数
//输入		iicMmpsda							//主机SDA复用口选择参数
//===============================================================================
void IIC_M_SETREUSE(enum IIC_M_MPSCL iicMmpscl,enum IIC_M_MPSDA iicMmpsda)
{
	u8 IIC_M_IOData,IIC_M_IOMP;
	IIC_M_IOMP = iicMmpscl & 0x07;
	IIC_M_IOData = (unsigned char)(0x01 << IIC_M_IOMP);
	MPSCL &= ~(0xFF << 0);
	if(iicMmpscl <= IIC_M_MPSCL_IOA7)
	{
		OEA |= (unsigned char)~IIC_M_IOData;
		PUA |= IIC_M_IOData;
		ANSA &= IIC_M_IOData;
	}		
	else if(iicMmpscl <= IIC_M_MPSCL_IOB7)
	{
		OEB |= (unsigned char)~IIC_M_IOData;
		PUB |= IIC_M_IOData;
		ANSB &= IIC_M_IOData;
		MPSCL |= (0x01 << 4);
	}	
	else if(iicMmpscl <= IIC_M_MPSCL_IOC7)
	{
		OEC |= (unsigned char)~IIC_M_IOData;
		PUC |= IIC_M_IOData;
		ANSC &= IIC_M_IOData;
		MPSCL |= (0x02 << 4);
	}
	else
	{
		OED |= (unsigned char)~IIC_M_IOData;
		PUD |= IIC_M_IOData;
		ANSD &= IIC_M_IOData;
		MPSCL |= (0x03 << 4);
	}
	MPSCL |= (unsigned char)(IIC_M_IOMP << 0);

	IIC_M_IOMP = iicMmpsda & 0x07;
	IIC_M_IOData = (unsigned char)(0x01 << IIC_M_IOMP);
	MPSDA &= ~(0xFF << 0);
	if(iicMmpsda <= IIC_M_MPSDA_IOA7)
	{
		OEA |= (unsigned char)~IIC_M_IOData;
		PUA |= IIC_M_IOData;
		ANSA &= IIC_M_IOData;
	}		
	else if(iicMmpsda <= IIC_M_MPSDA_IOB7)
	{
		OEB |= (unsigned char)~IIC_M_IOData;
		PUB |= IIC_M_IOData;
		ANSB &= IIC_M_IOData;
		MPSDA |= (0x01 << 4);
	}	
	else if(iicMmpsda <= IIC_M_MPSDA_IOC7)
	{
		OEC |= (unsigned char)~IIC_M_IOData;
		PUC |= IIC_M_IOData;
		ANSC &= IIC_M_IOData;
		MPSDA |= (0x02 << 4);
	}
	else
	{
		OED |= (unsigned char)~IIC_M_IOData;
		PUD |= IIC_M_IOData;
		ANSD &= IIC_M_IOData;
		MPSDA |= (0x03 << 4);
	}
	MPSDA |= (unsigned char)(IIC_M_IOMP << 0);
}
//===============================================================================
//***************************IIC主机时钟速度控制位设置函数***********************
//IIC主机时钟速度控制位设置
//输入		iicMcr							//主机IIC时钟速度控制位选择参数
//===============================================================================
void IIC_M_SETCR(enum IIC_M_CR iicMcr)
{
	I2CCR &= ~0x83;
	I2CCR |= iicMcr;		
}
//===============================================================================
//*****************************主机IICCR5-2位设置函数****************************
//主机IICCR5-2位设置
//输入		iicMst							//主机起始信号选择参数
//输入		iicMsto							//主机停止信号选择参数
//输入		iicMsi							//主机中断标志位选择参数
//输入		iicMaa							//主机应答位选择参数
//===============================================================================	
void IIC_M_SETIICCCR(enum IIC_M_ST iicMst,enum IIC_M_STO iicMsto,enum IIC_M_SI iicMsi,enum IIC_M_AA iicMaa)
{
	I2CCR &= ~(0x0F << 2);
	I2CCR |= (iicMst | iicMsto | iicMsi | iicMaa);
}
//===============================================================================
//*********************************I2C主机写*************************************
//I2C主机写：主机向从机发送数据
//输入		SlaverAddr						//当前从机地址
//输入		SlaverDataAddr					//当前写入RAM区的地址
//输入		*pWDataAddr						//当前写入RAM区数据地址的指针
//输入		WriteNumber						//当前写入的数据数量的个数
//===============================================================================		
void I2C_Master_Write(u8 SlaverAddr , u8 SlaverDataAddr , u8 *pWDataAddr , u8 WriteNumber)
{
	I2C_Start();							//起始指令
	Send_Add((unsigned char)(SlaverAddr + 0));//向从机地址
	Send_Data(SlaverDataAddr);				//向从机RAM地址写
	u8 i;
	for(i = 0;i < WriteNumber;i++)
	{
		Send_Data(*pWDataAddr);				//向从机RAM地址写的数据
		pWDataAddr++;
	}
	I2C_STOP();								//结束指令
}
//===============================================================================
//*********************************I2C主机读*************************************
//I2C主机读：主机先发送要读出RAM区的地址，再读数据依次放入I2C_MASTER_RDATA数组
//输入		SlaverAddr						//当前从机地址
//输入		SlaverDataAddr					//当前写入RAM区的地址
//输入		*pRDataAddr						//当前读取数据存放数组地址的指针
//输入		ReadNumber						//当前读取的数据数量的个数
//===============================================================================	
void I2C_Master_Read(u8 SlaverAddr , u8 SlaverDataAddr , u8 *pRDataAddr , u8 ReadNumber)
{
	FSR1 = *pRDataAddr;						//存放地址			
	I2C_Start();							//起始指令
	Send_Add((unsigned char)(SlaverAddr + 0));				//向从机地址
	Send_Data(SlaverDataAddr);				//发送要读出的RAM区地址
	I2C_Rstart();							//重复起始指令
	Send_Add((unsigned char)(SlaverAddr + 1));				//发送从机地址读
	for(;ReadNumber-- != 0;)			
	{
		Receive_Data();	
		*pRDataAddr = I2CDATA;				//读取的数据放入I2C_MASTER_RDATA数组
		pRDataAddr++;
	}
	STOP_Receive();
	I2C_STOP();
}
//===============================================================================
//*********************************产生起始信号**********************************
//产生起始信号
//===============================================================================
void I2C_Start()
{
	ST = ENABLE;
	SI = DISABLE;
	while(!SI);
	if(I2CSTA == STA_M_START)
	{
		ST = DISABLE;
	}
	else
	{
		MASTER_STATE_Err();
	}
}
//===============================================================================
//*********************************重复起始信号**********************************
//重复起始信号
//===============================================================================	
void I2C_Rstart(void)
{
	ST = ENABLE;
	SI = DISABLE;
	while(!SI);
	if(I2CSTA == STA_M_RSTART)
	{
		ST = DISABLE;
	}
	else
	{
		MASTER_STATE_Err();
	}
}
//===============================================================================
//******************************发送从机地址读、写*******************************
//发送从机地址读、写
//===============================================================================
void Send_Add(u8 DATA)
{
	I2CDATA = DATA;
	SI = DISABLE;
	while(!SI);
	if((DATA&0x01) != 1)					//写
	{
		if(I2CSTA == STA_M_W_ADRNACK)		//判断发送地址是否应答
		{
			STATE_W_ADRNACK();
		}
		else
		{
			if(I2CSTA != STA_M_W_ADRACK)
			{
				MASTER_STATE_Err();
			}
		}
	}
	else									//读
	{
		AA = ENABLE;
		if(I2CSTA == STA_M_R_ADRNACK)
		{
			STATE_W_ADRNACK();				//未应答
		}
		else
		{
			if(I2CSTA != STA_M_R_ADRACK)
			{
				MASTER_STATE_Err();
			}
		}
	}
}
//===============================================================================
//*********************************主机发送数据**********************************
//主机发送数据
//===============================================================================
void Send_Data(u8 DATA)
{
	I2CDATA = DATA;
	SI = DISABLE;
	while(!SI);
	if(I2CSTA == STA_M_W_DATNACK)
	{
		STATE_WDATNACK();
	}
	else
	{
		if(I2CSTA != STA_M_W_DATACK)
		{
			MASTER_STATE_Err();
		}
	}
}
//===============================================================================
//*********************************主机接收数据**********************************
//主机接收数据
//===============================================================================
void Receive_Data(void)
{
	SI = DISABLE;
	while(!SI);
	if(I2CSTA == STA_M_R_DATACK)
	{
		POSTINC1 = I2CDATA;
	}
	else
	{
		MASTER_STATE_Err();
	}
}
//===============================================================================
//*********************************主机停止接收**********************************
//主机停止接收
//===============================================================================
void STOP_Receive(void)
{
	AA = DISABLE;								//关闭应答
	SI = DISABLE;
	while(!SI);
	if(I2CSTA == STA_M_R_DATNACK)
	{
		INDF1 = I2CDATA;
	}
	else
	{
		MASTER_STATE_Err();
	}
}
//===============================================================================
//*********************************产生结束信号**********************************
//产生结束信号
//===============================================================================
void I2C_STOP(void)
{
	STO = ENABLE;
	SI = DISABLE;
}
//===============================================================================
//***********************************状态错误************************************
//状态错误
//===============================================================================
void MASTER_STATE_Err(void)
{
	/*串口打印Master State Err*/
	printf("%s\n","IIC Master State Err");
}
//===============================================================================
//*********************************写地址未应答**********************************
//写地址未应答
//===============================================================================
void STATE_W_ADRNACK(void)
{
	/*串口打印State Write AdrNACK*/
	printf("%s\n","IIC State Write AdrNACK");
}
//===============================================================================
//*********************************写数据未应答**********************************
//写数据未应答
//===============================================================================
void STATE_WDATNACK(void)
{
	/*串口打印State Write DatNACK*/
	printf("%s\n","IIC State Write DatNACK");
}
//===============================================================================
//*******************************IIC主机处理*************************************
//IIC主机写：向0xA0从机的RAM的0x40地址写数据
//IIC主机读：读0xA0从机的RAM的0x30地址里的数据并将读到的数据放入数组中通过串口
//打印出来
//===============================================================================
void I2C_MASTER_Work(void)					
{
	u8 i;
	for(i = 0;i < 15;i++)
	{
		I2C_MASTER_DATA[i] = i;					//定义主机向从机写的数据的数组
	}
	//(从机地址,写从机RAM区地址,写数组,写数组长度)				
	I2C_Master_Write(0xA0 , 0x40 , I2C_MASTER_DATA , sizeof(I2C_MASTER_DATA)/sizeof(I2C_MASTER_DATA[0]) );			//主机写
	for (i=0; i < 15; i++)
    {
        I2C_MASTER_DATA[i] = 0x00;				//将主机写的数据清零
    }
	//(从机地址,读从机RAM区地址,读取数据存放数组,读取数据存放数组长度)	
	I2C_Master_Read(0xA0 , 0x40 , I2C_MASTER_DATA , sizeof(I2C_MASTER_DATA)/sizeof(I2C_MASTER_DATA[0]));			//主机读
	for (i = 0; i < 15; i++)
    {
        printf("%02X ", (u8)I2C_MASTER_DATA[i]);//打印主机读的数据
    }
	printf("\r\n");								//打印换行
}

/*********************************END OF FILE************************************/