//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ADC.h"
#include "CMP.h"
#include "IIC_MASTER.h"
#include "IIC_SLAVER.h"
#include "PWM0.h"
#include "PWM1.h"
#include "SPI_MASTER.h"
#include "SPI_SLAVER.h"
#include "TC0.h"
#include "TC1.h"
#include "TC2G.h"
#include "USART.h"
#include "IO_INTERRUPT.h"
#include "EEPROM.h"
//===============================================================================
//-------------------------------------------------------------------------------
//用户可以自行更改
#define ADC_ON					1
#define CMP_ON					0
#define I2C_MASTER_ON			0
#define I2C_SLAVER_ON			0
#define SPI_MASTER_ON			0
#define SPI_SLAVER_ON			0
#define TC0_ON					0
#define TC1_ON					0
#define TC2G_ON					0
#define PWM0_ON					0
#define PWM1_ON					0
#define Interrupt_ON			0
#define Usart_ON				1
#define WDT_ON					0
#define EEPROM_ON				0
//===============================================================================
//********************************程序主函数************************************* 
//===============================================================================
void main(void)					  
{
	SYSTEM_INIT();                  		//系统初始化
	#if	ADC_ON
		ADC_INIT();							//ADC初始化
	#endif
	
	#if	CMP_ON
		CMP_INIT();							//CMP初始化
	#endif
	
	#if	I2C_MASTER_ON
		I2C_MASTER_INIT();					//I2C主机初始化
	#endif
	
	#if	I2C_SLAVER_ON
		I2C_SLAVER_INIT();					//I2C从机初始化
	#endif
	
	#if	Interrupt_ON
		IO_Interrupt_INIT();				//IO端口中断初始化
	#endif

	#if	PWM0_ON
		PWM0_INIT();						//PWM0初始化
	#endif

	#if	PWM1_ON
		PWM1_INIT();						//PWM1初始化
	#endif
	
	#if	SPI_MASTER_ON
		SPI_MASTER_INIT();					//SPI主机初始化
	#endif
	
	#if	SPI_SLAVER_ON
		SPI_SLAVER_INIT();					//SPI从机初始化
	#endif
	
	#if	TC0_ON
		TC0_INIT();							//TC0初始化
	#endif
	
	#if	TC1_ON
		TC1_INIT();							//TC1初始化
	#endif
	
	#if	TC2G_ON
		TC2G_INIT();						//TC2G初始化
	#endif
	
	#if	Usart_ON
		Usart_INIT();						//串口初始化
	#endif
	
	#if	EEPROM_ON
		EEPROM_INIT();						//EE_FLASH上电查找
	#endif
	while(1) 
	{
	CLRWDT();								//清除看门狗
	#if	ADC_ON
		ADC_Work();							//ADC处理程序
	#endif
	
	#if	CMP_ON
		CMP_Work();							//CMP处理程序
	#endif
	
	#if	PWM0_ON
		PWM0_Work();						//PWM0处理程序
	#endif
	
	#if	PWM1_ON
		PWM1_Work();						//PWM1处理程序
	#endif
	
	#if	TC0_ON
		TC0_Work();							//TC0处理程序
	#endif
	
	#if	TC1_ON
		TC1_Work();							//TC1处理程序
	#endif
	
	#if	TC2G_ON
		TC2G_Work();						//TC2G处理程序
	#endif
	
	#if	Interrupt_ON
		IO_Interrupt_Work();				//IO端口中断处理程序
	#endif
	
	#if	Usart_ON
		Usart_Work();						//串口处理程序
	#endif
	
	#if	I2C_MASTER_ON
		I2C_MASTER_Work();					//I2C主机处理程序
	#endif
	
	#if	I2C_SLAVER_ON
		I2C_SLAVER_Work();					//I2C从机处理程序
	#endif
	
	#if	SPI_MASTER_ON
		SPI_MASTER_Work();					//SPI主机处理程序
	#endif
	
	#if	SPI_SLAVER_ON
		SPI_SLAVER_Work();					//SPI从机处理程序
	#endif
	
	#if	EEPROM_ON
		EEPROM_Work();						//EEPROM处理程序
	#endif
	
	#if	WDT_ON
	/* 	OSCM = 0X05;						//高停低停
		STOP = 1;							//进休眠
		IOB7 = ~IOB7; */
	#endif
  }
}
//===============================================================================
//******************************高优先级中断服务子程序***************************
//高优先级中断入口需调用空函数做断点保护
//注：中断处理调用子函数处理，不要再这里直接处理
//===============================================================================
void interrupt high_priority int_h(void)		
{
	#asm
		call  _breakpoint_protect,f			
	#endasm	
	
	#if TC0_ON
		TC0_Interrupt();					//TC0中断处理程序
	#endif
	
	#if TC1_ON
		TC1_Interrupt();					//TC1中断处理程序
	#endif
	
	#if Usart_ON
		Usart_Interrupt();					//串口中断处理程序
	#endif
	
	#if Interrupt_ON
		IO_Interrupt();						//端口中断处理程序
	#endif
	
	#if SPI_SLAVER_ON
		SPI_S_Interrupt();					//SPI中断处理程序
	#endif
}
//===============================================================================
//******************************低优先级中断服务子程序***************************
//低优先级中断入口需调用空函数做断点保护
//注：中断处理调用子函数处理，不要再这里直接处理
//===============================================================================
void interrupt low_priority int_l(void)		
{
	#asm
		call  _breakpoint_protect,f			
	#endasm	
	
	#if TC1_ON
		if(TC1IF)
		{	
			/* TC1中断是高、低优先级同时触发,程序同时使能高、低优先级时,低优先级中断处理程序中,须查询TC1中断标志位,如有置起,清0 */
			TC1IF = 0;						
		}
	#endif
	
	#if TC2G_ON
		TC2G_Interrupt();					//TC2G中断处理程序
	#endif
	
	#if I2C_SLAVER_ON
		IICSLAVER_Interrupt();				//IIC从机中断处理程序
	#endif
}
//===============================================================================
//***********************************空函数**************************************
//空函数做断点保护
//用户不可更改
//===============================================================================
void breakpoint_protect()
{
	
}
//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置个IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================		
void SYSTEM_INIT(void)
{
//----------------------------------------------------
//Init 系统时钟
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	ANSA = 0x00;               //0:数字口	1:模拟口 
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	PDA = 0x00;				   //0:下拉关闭 1:下拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	//IOB
	ANSB = 0x00;  
	PUB = 0x00;                
	PDB = 0x00;				   
	IOB = 0x00;                
	OEB = 0xFF;                
	//IOC
	ANSC = 0x00;  
	PUC = 0x00;               
	PDC = 0x00;				   
	IOC = 0x00;                
	OEC = 0xFF;              
	//IOD
	ANSD = 0x00;  
	PUD = 0x00;               
	PDD = 0x00;				   
	IOD = 0x00;               
	OED = 0xFF; 
//----------------------------------------------------     
//Init Interrupt
	GIEH = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
	GIEL = 0;                  //1:全局中断低优先级中断使能,0:屏蔽全局中断低优先级中断
}
//===============================================================================
//************************************延时函数***********************************
//延时100ms程序，时长可通过修改Delay_Count进行修改
//t=Delay_Count*1ms 
//===============================================================================	
void Delay_1ms(u16 Delay_Count)
{
	u16 i;
	u16 Delay_Count1;
	for(i = Delay_Count;i > 0;i--)
	{
		for(Delay_Count1 = 141;Delay_Count1 > 0;Delay_Count1--)
		{
		
		}
	}
}	

/*********************************END OF FILE************************************/