//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "TC0.h"
#include "PWM0.h"
//===============================================================================
//*********************************PWM0X初始化************************************
//TC0设置：8位模式，16M，高频系统时钟，1:128分频
//PWM0配置,复用端口选择PWM00/01/02/03输出端口依次为IOC4/5/6/7,数字输出口关闭上下拉
//高电平有效,频率500Hz(PWM0周期计算不考虑TC0后分频比)
//===============================================================================
void PWM0_INIT(void)				
{
	/* TC0初始化必须为8位模式 */
	/* TC0模式设置,8位模式 */
	TC0_SETMODE(TC0_MODE_8);
	/* TC0内部高频时钟选择设置，16M(24M禁用) */
	TC0_SETOSCS(TC0_OSCS_16M);
	/* TC0时钟源设置,高频系统时钟 */
	TC0_SETCLOCK(TC0_CLOCK_Fosch);
	/* TC0预分频比设置,预分频比1:128,后分频比1:5 */
	TC0_SETPREDIVISION(TC0_PREDIVISION_128 , TC0_DIVISION_5);
	/* 计数器设置  t =计数/（时钟/分频）*/
	/* TC0:8位模式 计数=TC0CL_DATA-TC0CH_DATA */
	/* TC0:16位模式 计数=0xFFFF-[TC0CH_DATA:TC0CL_DATA] */
	TC0_SETTC0C(TC0_TC0CH_0 , TC0_TC0CL_249);										
	/*TC0开关设置,使能TC0*/
	TC0EN = ENABLE;
	/*PWM0复用口选择,PWM00/01/02/03输出端口依次为IOC4/5/6/7*/
	PWM0X_SETMPPWM(PWM00_IOC4);
	/* PWM0X输出极性设置，PWM00\PWM01\PWM02\PWM03高电平有效 */
	PWM0X_SETPOLARITY(PWM00_POLARITY_HIGH , PWM01_POLARITY_HIGH , PWM02_POLARITY_HIGH , PWM03_POLARITY_HIGH);
	/* PWM0X开关，PWM00\PWM01\PWM02\PWM03使能 */
	PWM00EN = ENABLE;
	PWM01EN = ENABLE;
	PWM02EN = ENABLE;
	PWM03EN = ENABLE;
	/* 占空比设置，PWM00D\PWM01D\PWM02D\PWM03D均为124 */
	PWM0X_SETPWM0XD(PWM00_PWM00D_125 , PWM01_PWM01D_125 , PWM02_PWM02D_125 , PWM03_PWM03D_125);	
}
//===============================================================================
//********************************PWM0X复用口设置函数****************************
//PWM0X复用口设置
//输入		pwm0xMppwm						//PWM0复用口选择参数
//===============================================================================
void PWM0X_SETMPPWM(enum MPPWM0_SELECT pwm0xMppwm)
{
	u8 PWM0_IOData;
	u8 PWM0_IOMP;
	PWM0_IOMP = pwm0xMppwm & 0x01;
	if(PWM0_IOMP)
	{
		PWM0_IOData = 0xF0;
	}else
	{
		PWM0_IOData = 0x0F;
	}
	MPPWM0 &= ~(0xFF << 0);
	if(pwm0xMppwm <= PWM00_IOA4)
	{
		OEA |= PWM0_IOData;
		ANSA &= (unsigned char)~PWM0_IOData;
	}
	else if(pwm0xMppwm <= PWM00_IOB4)
	{
		OEB |= PWM0_IOData;
		ANSB &= (unsigned char)~PWM0_IOData;
		MPPWM0 |= (0x01 << 4);
	}	
	else if(pwm0xMppwm <= PWM00_IOC4)
	{
		OEC |= PWM0_IOData;
		ANSC &= (unsigned char)~PWM0_IOData;	
		MPPWM0 |= (0x02 << 4);
	}
	else
	{
		OED |= PWM0_IOData;
		ANSD &= (unsigned char)~PWM0_IOData;
		MPPWM0 |= (0x03 << 4);
	}
	MPPWM0 |= (unsigned char)(PWM0_IOMP << 2);
}
//===============================================================================
//*****************************PWM0X设置输出极性设置函数*************************
//PWM0X设置输出极性设置
//输入		pwm00M							//PWM00设置输出极性控制选择参数
//输入		pwm01M							//PWM01设置输出极性控制选择参数
//输入		pwm02M							//PWM02设置输出极性控制选择参数
//输入		pwm03M							//PWM03设置输出极性控制选择参数
//===============================================================================
void PWM0X_SETPOLARITY(enum PWM00_POLARITY pwm00M,enum PWM01_POLARITY pwm01M,enum PWM02_POLARITY pwm02M,enum PWM03_POLARITY pwm03M)
{
	PWM00CR	&= ~(0x01 << 5);
	PWM00CR |= pwm00M;
	PWM01CR	&= ~(0x01 << 5);
	PWM01CR |= pwm01M;
	PWM02CR	&= ~(0x01 << 5);
	PWM02CR |= pwm02M;
	PWM03CR	&= ~(0x01 << 5);
	PWM03CR |= pwm03M;
}
//===============================================================================
//********************************PWM0X计数设置函数******************************
//PWM0X计数设置
//输入		pwm00Pwm00d						//PWM00计数设置选择参数
//输入		pwm01Pwm01d						//PWM01计数设置选择参数
//输入		pwm02Pwm02d						//PWM02计数设置选择参数
//输入		pwm03Pwm03d						//PWM03计数设置选择参数
//===============================================================================
void PWM0X_SETPWM0XD(enum PWM00_PWM00D pwm00Pwm00d,enum PWM01_PWM01D pwm01Pwm01d,enum PWM02_PWM02D pwm02Pwm02d,enum PWM03_PWM03D pwm03Pwm03d)
{
	PWM00D &= ~(0xFF << 0);
	PWM00D |= (pwm00Pwm00d << 0);
	PWM01D &= ~(0xFF << 0);
	PWM01D |= (pwm01Pwm01d << 0);
	PWM02D &= ~(0xFF << 0);
	PWM02D |= (pwm02Pwm02d << 0);
	PWM03D &= ~(0xFF << 0);
	PWM03D |= (pwm03Pwm03d << 0);
}
//===============================================================================
//******************************PWM0X输出控制设置函数****************************
//PWM0X输出控制设置
//输入		pwm00Oe							//PWM00设置输出控制选择参数
//输入		pwm01Oe							//PWM01设置输出控制选择参数
//输入		pwm02Oe							//PWM02设置输出控制选择参数
//输入		pwm03Oe							//PWM03设置输出控制选择参数
//===============================================================================
void PWM0X_SETOUT(enum PWM00_OUT pwm00Oe,enum PWM01_OUT pwm01Oe,enum PWM02_OUT pwm02Oe,enum PWM03_OUT pwm03Oe)
{
	PWM00CR	&= ~(0x01 << 6);
	PWM00CR |= pwm00Oe;
	PWM01CR	&= ~(0x01 << 6);
	PWM01CR |= pwm01Oe;
	PWM02CR	&= ~(0x01 << 6);
	PWM02CR |= pwm02Oe;
	PWM03CR	&= ~(0x01 << 6);
	PWM03CR |= pwm03Oe;
}
//===============================================================================
//********************************PWM0X处理程序**********************************
//方波循环开启100ms,关闭100ms
//===============================================================================
void PWM0_Work(void)				
{
	/* PWM0X设置输出控制,端口输出 */
	PWM0X_SETOUT(PWM00_OUT_PWM , PWM01_OUT_PWM , PWM02_OUT_PWM , PWM03_OUT_PWM);
	Delay_1ms(100);
	/* PWM0X设置输出控制,用作IO */
	PWM0X_SETOUT(PWM00_OUT_IO , PWM01_OUT_IO , PWM02_OUT_IO , PWM03_OUT_IO);
	Delay_1ms(100);
}

/*********************************END OF FILE************************************/