//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "TC1.h"
#include "PWM1.h"
//===============================================================================
//*********************************PWM1初始化************************************
//TC1设置：16位模式，16M，高频系统时钟，1:64分频
//PWM1配置,PWM10输出端口为IOC0、PWM11输出端口为IOC1，数字输出口关闭上下拉,频率10Hz
//互补输出，前后死区均为15us
//===============================================================================
void PWM1_INIT(void)
{
	/* TC1模式设置,递增模式 */
	TC1_SETMODE(TC1_MODE_Incresing);
	/* TC1时钟源设置,高频系统时钟 */
	TC1_SETCLOCK(TC1_CLOCK_Fosch);
	/* TC1预分频比设置,预分频比1:64 */
	TC1_SETPREDIVISION(TC1_PREDIVISION_64);
	/* TC1:计数=[TC1PRH_DATA:TC1PRL_DATA]-[TC1CH_DATA:TC1CL_DATA] */
	/* TC1C设置，[TC1CH_DATA:TC1CL_DATA]=0x0000 */
	TC1_SETTC1C(TC1_TC1CH_0 , TC1_TC1CL_0);
	/* TC1PR设置，[TC1PRH_DATA:TC1PRL_DATA]=0x61A7 */
	TC1_SETTC1PR(TC1_TC1PRH_97 , TC1_TC1PRL_167);	//t =计数/（时钟/分频）
	/* TC1模块使能位,使能TC1 */
	TC1EN = ENABLE;
	/*PWM1复用口选择,PWM10输出端口为IOC0、PWM11输出端口为IOC1*/
	PWM1_SETMPPWM1(PWM10_IOC0 , PWM11_IOC1);
	/* PWM1输出模式,PWM10\PWM11高电平有效 */
	PWM1_SETPWM1M(PWM1_PWM10M_H , PWM1_PWM11M_H);
	/* PWM1模式,互补模式 */
	PWM1_SETPWM1S(PWM1_PWM1S_Comp);
	/* 数据寄存器 PWM10DH:0X30\PWM10DL:0XD6\PWM11DH:0X0F\PWM11DL:0X0F*/
	PWM1X_SETPWM1XD(PWM10_PWM10DH_48 , PWM10_PWM10DL_211 , PWM11_PWM11DH_15 , PWM11_PWM11DL_15);
	/* PWM1模块使能位,PWM10\PWM11使能 */
	PWM10EN = ENABLE;
	PWM11EN = ENABLE;
}
//===============================================================================
//*********************************PWM1复用口设置函数****************************
//PWM1复用口设置·
//输入		pwm10Mppwm10						//PWM10复用口选择参数
//输入		pwm11Mppwm11						//PWM11复用口选择参数
//===============================================================================
void PWM1_SETMPPWM1(enum MPPWM10_SELECT pwm10Mppwm10,enum MPPWM11_SELECT pwm11Mppwm11)
{
	u8 PWM1_IOData,PWM1_IOMP;
	PWM1_IOMP = pwm10Mppwm10 & 0x07;
	PWM1_IOData = (unsigned char)(0x01 << PWM1_IOMP);
	MPPWM10 &= ~(0xFF << 0);
	if(pwm10Mppwm10 <= PWM10_IOA7)
	{
		OEA |= PWM1_IOData;
		ANSA &= (unsigned char)~PWM1_IOData;
	}		
	else if(pwm10Mppwm10 <= PWM10_IOB7)
	{
		OEB |= PWM1_IOData;
		ANSB &= (unsigned char)~PWM1_IOData;
		MPPWM10 |= (0x01 << 4);
	}	
	else if(pwm10Mppwm10 <= PWM10_IOC7)
	{
		OEC |= PWM1_IOData;
		ANSC &= (unsigned char)~PWM1_IOData;
		MPPWM10 |= (0x02 << 4);
	}
	else if(pwm10Mppwm10 <= PWM10_IOD1)
	{
		OED |= PWM1_IOData;
		ANSD &= (unsigned char)~PWM1_IOData;
		MPPWM10 |= (0x03 << 4);
	}
	MPPWM10 |= (unsigned char)(PWM1_IOMP << 0);

	MPPWM11 &= ~(0xFF << 0);
	PWM1_IOMP = pwm11Mppwm11 & 0x07;
	PWM1_IOData = (unsigned char)(0x01 << PWM1_IOMP);
	if(pwm11Mppwm11 <= PWM11_IOA7)
	{
		OEA |= PWM1_IOData;
		ANSA &= (unsigned char)~PWM1_IOData;
	}		
	else if(pwm11Mppwm11 <= PWM11_IOB7)
	{
		OEB |= PWM1_IOData;
		ANSB &= (unsigned char)~PWM1_IOData;
		MPPWM11 |= (0x01 << 4);
	}	
	else if(pwm11Mppwm11 <= PWM11_IOC7)
	{
		OEC |= PWM1_IOData;
		ANSC &= (unsigned char)~PWM1_IOData;
		MPPWM11 |= (0x02 << 4);
	}
	else if(pwm11Mppwm11 <= PWM11_IOD1)
	{
		OED |= PWM1_IOData;
		ANSD &= (unsigned char)~PWM1_IOData;
		MPPWM11 |= (0x03 << 4);
	}
	MPPWM11 |= (unsigned char)(PWM1_IOMP << 0);
}
//===============================================================================
//*******************************PWM1输出模式设置函数****************************
//PWM1输出模式设置
//输入		pwm1Pwm10m							//PWM10输出模式选择参数
//输入		pwm1Pwm11m							//PWM11输出模式选择参数
//===============================================================================
void PWM1_SETPWM1M(enum PWM1_PWM10M pwm1Pwm10m,enum PWM1_PWM11M pwm1Pwm11m)
{
	PWM1CR &= ~0x24;
	PWM1CR |= (pwm1Pwm10m | pwm1Pwm11m);
}
//===============================================================================
//*********************************PWM1模式设置函数******************************
//PWM1模式设置
//输入		pwm1Pwm1s							//PWM1模式选择参数
//===============================================================================
void PWM1_SETPWM1S(enum PWM1_PWM1S pwm1Pwm1s)
{
	PWM1CR &= ~(0x01 << 1);
	PWM1CR |= pwm1Pwm1s;
}
//===============================================================================
//********************************PWM1X计数设置函数******************************
//PWM1X计数设置
//输入		pwm10Pwm10dh						//PWM10数据高位寄存器选择参数
//输入		pwm10Pwm10dl						//PWM10数据低位寄存器选择参数
//输入		pwm11Pwm11dh						//PWM11数据高位寄存器选择参数
//输入		pwm11Pwm10dl						//PWM11数据低位寄存器选择参数
//===============================================================================
void PWM1X_SETPWM1XD(enum PWM10_PWM10DH pwm10Pwm10dh,enum PWM10_PWM10DL pwm10Pwm10dl,enum PWM11_PWM11DH pwm11Pwm11dh,enum PWM11_PWM11DL pwm11Pwm11dl)
{
	PWM10DH &= ~(0xFF << 0);
	PWM10DH |= (pwm10Pwm10dh << 0);
	PWM10DL &= ~(0xFF << 0);
	PWM10DL |= (pwm10Pwm10dl << 0);
	PWM11DH &= ~(0xFF << 0);
	PWM11DH |= (pwm11Pwm11dh << 0);
	PWM11DL &= ~(0xFF << 0);
	PWM11DL |= (pwm11Pwm11dl << 0);
}
//===============================================================================
//*****************************PWM1波形输出使能设置函数**************************
//PWM1波形输出使能设置
//输入		pwm1Pwm10oe							//PWM10波形输出使能选择参数
//输入		pwm1Pwm11oe							//PWM11波形输出使能选择参数
//===============================================================================
void PWM1_SETPWM1OE(enum PWM1_PWM10OE pwm1Pwm10oe,enum PWM1_PWM11OE pwm1Pwm11oe)
{
	PWM1CR &= ~0x48;
	PWM1CR |= (pwm1Pwm10oe | pwm1Pwm11oe);
}
//===============================================================================
//********************************PWM1处理程序***********************************
//方波循环开启1s,关闭1s
//===============================================================================
void PWM1_Work(void)
{
	/* PWM10、PWM10设置输出控制,端口输出 */
	PWM1_SETPWM1OE(PWM1_PWM10OE_PWM10 , PWM1_PWM11OE_PWM11);			
	Delay_1ms(1000);	
	/* PWM10、PWM10设置输出控制,用作IO */
	PWM1_SETPWM1OE(PWM1_PWM10OE_IO , PWM1_PWM11OE_IO);
	Delay_1ms(1000);		
}

/*********************************END OF FILE************************************/