//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "SPI_MASTER.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
u8 R_SPI_MASTER_RecData;					//主机从从机接收到的数据返回值放在R_SPI_MASTER_RecData中
u8 R_SPI_M_SEND_DATA;						//发送0x00-0x0F数据
//===============================================================================
//*******************************SPI主机初始化***********************************
//SPI主机初始化:发送口设置为输出模式,接收口设置为输入模式,SSN无效,作为主机,
//SPI时钟速度控制位设置Fcpu/32,时钟极性选择空间状态SCK为低,第一个时钟沿采样
//===============================================================================
void SPI_MASTER_INIT(void)
{
	/*端口设置：发送口设置为输出模式，接收口设置为输入模式*/
	SPI_M_SETIO();
	/* SPI时钟速度控制位设置,Fcpu/32 */
	SPI_M_SETSPCR(SPI_M_SPCR_32);
	/* SPI使能位设置,使能 */
	SPIEN = ENABLE;
	/* SPI SNN控制设置,SSN无效 */
	SPI_M_SETSSOE(SPI_M_SSOE_N);
	/* SPI主从控制设置,作为主机 */
	SPI_M_SETMSTR(SPI_M_MSTR_Master);
	/* SPI时钟极性选择设置,空间状态SCK为低|SPI时钟相位选择设置,第一个时钟沿采样 */
	SPI_M_SETCP(SPI_M_CPOL_L,SPI_M_CPHA_1);
}
//===============================================================================
//****************************SPI主机端口设置函数********************************
//SPI主机端口设置
//IOB5										//SPI主机SSN端口选择参数
//IOB4										//SPI主机SCK端口选择参数
//IOB3										//SPI主机MOSI端口选择参数,设置为输出模式
//IOB2										//SPI主机MISO端口选择参数,设置为输入模式
//===============================================================================
void SPI_M_SETIO(void)
{
	/* SPI主机SSN端口设置选择 */
	OEB5 = 1;
	IOB5 = 1;
	ANSB5 = 0;
	/* SPI主机SCK端口设置选择 */
	OEB4 = 1;
	ANSB4 = 0;
	/* SPI主机MOSI端口设置选择 */
	OEB3 = 1;
	ANSB3 = 0;
	/* SPI主机MISO端口设置选择 */
	OEB2 = 0;
	ANSB2 = 0;
}
//===============================================================================
//*************************SPI时钟速度控制位设置函数*****************************
//SPI时钟速度控制位设置
//输入		spimSpcr						//SPI时钟速度控制位选择参数
//===============================================================================
void SPI_M_SETSPCR(enum SPI_M_SPCR spimSpcr)
{
	SPICR &= ~0x83;
	SPICR |= spimSpcr;
}
//===============================================================================
//****************************SPI SNN控制设置函数********************************
//SPI SNN控制设置
//输入		spimSsoe						//SPI SNN控制选择参数
//===============================================================================
void SPI_M_SETSSOE(enum SPI_M_SSOE spimSsoe)
{
	SPICR &= ~(0x01 << 5);
	SPICR |= spimSsoe;
}
//===============================================================================
//****************************SPI主从控制设置函数********************************
//SPI主从控制设置
//输入		spimMstr						//SPI主从控制选择参数
//===============================================================================
void SPI_M_SETMSTR(enum SPI_M_MSTR spimMstr)
{
	SPICR &= ~(0x01 << 4);
	SPICR |= spimMstr;
}
//===============================================================================
//*************************SPI时钟极性/相位选择设置******************************
//SPI时钟极性/相位选择设置
//输入		spimCpol						//SPI时钟极性选择参数
//输入		spimCpha						//SPI时钟相位选择参数
//===============================================================================
void SPI_M_SETCP(enum SPI_M_CPOL spimCpol,enum SPI_M_CPHA spimCpha)
{
	SPICR &= ~(0x03 << 2);
	SPICR |= (spimCpol | spimCpha);
}
//===============================================================================
//*********************************SPI主机处理***********************************
//SPI主机处理:主机向从机发送0x00-0x0F，接收并打印从机发送的内容
//===============================================================================
void SPI_MASTER_Work(void)
{
	for(R_SPI_M_SEND_DATA = 0;R_SPI_M_SEND_DATA < 16;R_SPI_M_SEND_DATA++)
	{
		R_SPI_MASTER_RecData = SPI_Send(R_SPI_M_SEND_DATA);
		/* 打印接收到的从机数据，接收到第一个是0x0F，之后一次接收0x00-0x0F */
		printf("SPI Master Receive %02X\r\n", R_SPI_MASTER_RecData);
	}
}
//===============================================================================
//****************************SPI发送并接收数据函数******************************
//发送并接收数据,并等待直到传输完成或写冲突
//该范例使用的是第一个时钟沿采样，第一个时钟沿采样是必须在每次传输数据完成前前将
//SSN保持低电平，传输完成后设置成高电平
//===============================================================================
unsigned char SPI_Send(unsigned char R_Data)
{
	u8 R_SPI_MASTER_DATA;
	IOB5 = 0;								//在数据传输完成前SSN保持低电平状态
	SPIDATA = R_Data;
	while(!SPIF);
	R_SPI_MASTER_DATA = SPIDATA;
	IOB5 = 1;
	return(SPIDATA);
}

//*********************************END OF FILE***********************************