//===============================================================================
//===============================================================================
#ifndef __SPIMASTER_H__
#define __SPIMASTER_H__

#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

#define ENABLE							1
#define DISABLE							0
/* SPI时钟速度控制位 */
enum SPI_M_SPCR
{
	SPI_M_SPCR_2 = 0x00,//Fcpu/2
	SPI_M_SPCR_4 = 0x01,//Fcpu/4
	SPI_M_SPCR_8 = 0x02,//Fcpu/8
	SPI_M_SPCR_16 = 0x03,//Fcpu/16
	SPI_M_SPCR_32 = 0x80,//Fcpu/32
	SPI_M_SPCR_64 = 0x81,//Fcpu/64
	SPI_M_SPCR_128 = 0x82,//Fcpu/128
	SPI_M_SPCR_NOP = 0x83,//主模式下不产生时钟,当CPOL为1时,SCKO输出为高阻态，否则为低电平
};
/* SPI SNN控制 */
enum SPI_M_SSOE
{
	SPI_M_SSOE_Y = 0x00,//SSN有效
	SPI_M_SSOE_N = 0x20,//SSN无效
};
/* SPI主从控制 */
enum SPI_M_MSTR
{
	SPI_M_MSTR_Slave = 0x00,//作为从机
	SPI_M_MSTR_Master = 0x10,//作为主机
};
/* SPI时钟极性选择 */
enum SPI_M_CPOL
{
	SPI_M_CPOL_L = 0x00,//空间状态SCK为低
	SPI_M_CPOL_H = 0x08,//空间状态SCK为高
};
/* SPI时钟相位选择 */
enum SPI_M_CPHA
{
	SPI_M_CPHA_1 = 0x00,//第一个时钟沿采样
	SPI_M_CPHA_2 = 0x04,//第二个时钟沿采样
};
//=================================SPI主机函数声明===========================================
void SYSTEM_INIT(void);//系统初始化
void Delay_1ms(u16 Delay_Count);//延时
void SPI_M_SETIO(void);//SPI主机端口设置
void SPI_M_SETSPCR(enum SPI_M_SPCR spimSpcr);//SPI时钟速度控制位设置
void SPI_M_SETSSOE(enum SPI_M_SSOE spimSsoe);//SPI SNN控制设置
void SPI_M_SETMSTR(enum SPI_M_MSTR spimMstr);//SPI主从控制设置
void SPI_M_SETCP(enum SPI_M_CPOL spimCpol,enum SPI_M_CPHA spimCpha);//SPI时钟极性/相位选择设置
void SPI_MASTER_Work(void);//SPI主机处理程序
void SPI_MASTER_INIT(void);//SPI主机初始化
unsigned char SPI_Send(unsigned char R_Data);//SPI主机发送并接收数据

#endif