//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "SPI_SLAVER.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
bit	B_SPI_Slave_State_Flag;					//状态错误标志位
bit B_SPI_RecOK_Flag;						//传输完成标志位
u8 R_SPI_S_RECDATA;							//从机接收到的数据放在R_SPI_S_RECDATA中
//===============================================================================
//*******************************SPI从机初始化***********************************
//SPI从机初始化:发送口设置为输出模式,接收口设置为输入模式,SSN无效,作为从机,
//SPI时钟速度控制位设置Fcpu/32,时钟极性选择空间状态SCK为低,第一个时钟沿采样
//===============================================================================
void SPI_SLAVER_INIT(void)
{
	/*端口设置*/
	/*端口设置：发送口设置为输出模式，接收口设置为输入模式*/
	SPI_S_SETIO();
	/*SPI时钟速度控制位设置,Fcpu/32*/
	SPI_S_SETSPCR(SPI_S_SPCR_32);
	/*SPI SNN控制设置,SSN无效*/
	SPI_S_SETSSOE(SPI_S_SSOE_N);
	/*SPI主从控制设置,作为从机*/
	SPI_S_SETMSTR(SPI_S_MSTR_Slave);
	/* SPI时钟极性选择设置,空间状态SCK为低|SPI时钟相位选择设置,第一个时钟沿采样 */
	SPI_S_SETCP(SPI_S_CPOL_L,SPI_S_CPHA_1);
	/*SPI使能位设置,使能*/
	SPIEN = ENABLE;
	/*中断设置*/
	/*开启SPI中断和总中断*/
	SPIF2 = DISABLE;
	SPIIE = ENABLE;
	SPIP = DISABLE;
	GIEH = ENABLE;
	/*从机发送第一个数据0x0F*/
	SPIDATA = 0x0F;
}
//===============================================================================
//****************************SPI从机端口设置函数********************************
//SPI从机端口设置
//输入		spisSsn							//SPI从机SSN端口选择参数
//输入		spisSck							//SPI从机SCK端口选择参数
//输入		spisMosi						//SPI从机MOSI端口选择参数
//输入		spisMiso						//SPI从机MISO端口选择参数
//===============================================================================
void SPI_S_SETIO(void)
{
	/* SPI从机SSN端口设置选择 */
	OEB5 = 0;
	ANSB5 = 0;
	/* SPI从机SCK端口设置选择 */
	OEB4 = 0;
	ANSB4 = 0;
	/* SPI从机MOSI端口设置选择 */
	OEB3 = 1;
	ANSB3 = 0;
	/* SPI从机MISO端口设置选择 */
	OEB2 = 0;
	ANSB2 = 0;
}
//===============================================================================
//*************************SPI时钟速度控制位设置函数*****************************
//SPI时钟速度控制位设置
//输入		spisSpcr						//SPI时钟速度控制位选择参数
//===============================================================================
void SPI_S_SETSPCR(enum SPI_S_SPCR spisSpcr)
{
	SPICR &= ~0x83;
	SPICR |= spisSpcr;
}
//===============================================================================
//****************************SPI使能位设置函数**********************************
//SPI使能位设置
//输入		spisSpien						//SPI使能位设置选择参数
//===============================================================================
void SPI_S_SETSPIEN(enum SPI_S_SPIEN spisSpien)
{
	SPICR &= ~(0x01 << 6);
	SPICR |= spisSpien;
}
//===============================================================================
//****************************SPI SNN控制设置函数********************************
//SPI SNN控制设置
//输入		spisSsoe						//SPI SNN控制选择参数
//===============================================================================
void SPI_S_SETSSOE(enum SPI_S_SSOE spisSsoe)
{
	SPICR &= ~(0x01 << 5);
	SPICR |= spisSsoe;
}
//===============================================================================
//****************************SPI主从控制设置函数********************************
//SPI主从控制设置
//输入		spisMstr						//SPI主从控制选择参数
//===============================================================================
void SPI_S_SETMSTR(enum SPI_S_MSTR spisMstr)
{
	SPICR &= ~(0x01 << 4);
	SPICR |= spisMstr;
}
//===============================================================================
//*************************SPI时钟极性/相位选择设置******************************
//SPI时钟极性/相位选择设置
//输入		spisCpol						//SPI时钟极性选择参数
//输入		spisCpha						//SPI时钟相位选择参数
//===============================================================================
void SPI_S_SETCP(enum SPI_S_CPOL spisCpol,enum SPI_S_CPHA spisCpha)
{
	SPICR &= ~(0x03 << 2);
	SPICR |= (spisCpol | spisCpha);
}
//===============================================================================
//********************************SPI从机中断处理函数****************************
//SPI从机中断处理函数
//判断是是否传输完成，并将接收到的数据保存进R_SPI_S_RECDATA中
//===============================================================================
void SPI_S_Interrupt(void)
{
	if(SPIIE == 1)							//防止主机程序进入中断
	{
		if(SPIF2 == 1)
		{
			if(SPIF == 1)					//数据传输完成
			{
				B_SPI_RecOK_Flag = 1;
				R_SPI_S_RECDATA = SPIDATA;	//读接收到的数据
			}
			if(MODF == 1)					//发生模式错误
			{
				B_SPI_Slave_State_Flag = 1;
			}
		}
	}
}
//===============================================================================
//*********************************SPI从机处理***********************************
//SPI从机处理:从机发送第一个数据0x0F，再从主机接收到0x00-0x0F并依次发给主机
//接收正确打印接收到的数据
//===============================================================================
void SPI_SLAVER_Work(void)
{
	if(B_SPI_Slave_State_Flag == 1)			//发生模式错误，打印SPI Slave State Error
	{
		B_SPI_Slave_State_Flag = 0;
		printf("%s\n","SPI Slave State Error");
	}
	if(B_SPI_RecOK_Flag == 1)				//数据传输完成
	{
		B_SPI_RecOK_Flag = 0;
		SPIDATA = R_SPI_S_RECDATA;			//将从主机接收到的数据再发给主机
		/* 打印从主机接收到的数据，从0x00-0x0F */
		printf("%s\n","SPI Slave Receive OK");
	}
}

/*********************************END OF FILE************************************/