//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "TC0.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
bit	b_TC0_Flag;								//TC0进入中断后标志位置1
//===============================================================================
//********************************TC0初始化**************************************
//TC0初始化:TC0设置8位模式,高频系统时钟选择16M,预分频比设置1:128,分频比1:5
//TC0CH设置为0，TC0CL设置为249
//===============================================================================
void TC0_INIT(void)
{
	/* TC0模式设置,8位模式 */
	TC0_SETMODE(TC0_MODE_8);
	/* TC0内部高频时钟选择设置，16M(24M禁用) */
	TC0_SETOSCS(TC0_OSCS_16M);
	/* TC0时钟源设置,高频系统时钟 */
	TC0_SETCLOCK(TC0_CLOCK_Fosch);
	/* TC0预分频比设置,预分频比1:128,分频比1:5 */
	TC0_SETPREDIVISION(TC0_PREDIVISION_128 , TC0_DIVISION_5);
	/* 计数器设置  t =计数/（时钟/分频）*/
	/* TC0:8位模式 计数=TC0CL_DATA-TC0CH_DATA */
	/* TC0:16位模式 计数=0xFFFF-[TC0CH_DATA:TC0CL_DATA] */
	TC0_SETTC0C(TC0_TC0CH_0 , TC0_TC0CL_249);										
	/*TC0开关设置,使能TC0*/
	TC0EN = ENABLE;
	/*中断设置,低优先级*/
	TC0IE = ENABLE;
	TC0IF = DISABLE;
	TC0IP = DISABLE;
	GIEH = ENABLE;
}
//===============================================================================
//******************************TC0模式设置函数**********************************
//TC0模式设置
//输入		tc0Mode							//TC0模式选择参数
//===============================================================================
void TC0_SETMODE(enum TC0_MODE tc0Mode)
{
	T0CR &= ~(0x01 << 6);
	T0CR |= tc0Mode;
}
//===============================================================================
//***************************TC0内部高频时钟选择设置函数*************************
//TC0内部高频时钟选择设置
//输入		tc0Oscs							//TC0内部高频时钟选择参数(24M禁用)
//===============================================================================
void TC0_SETOSCS(enum TC0_OSCS tc0Oscs)
{
	T0CR &= ~(0x01 << 5);
	T0CR |= tc0Oscs;
}
//===============================================================================
//*****************************TC0时钟源设置函数*********************************
//TC0时钟源设置
//输入		tc0Clock						//TC0时钟源选择参数
//===============================================================================
void TC0_SETCLOCK(enum TC0_CLOCK tc0Clock)
{
	T0CR &= ~(0x03 << 3);
	T0CR |= tc0Clock;
	if(tc0Clock == TC0_CLOCK_T0CKI)
	{
		ANSA4 = 0;
		OEA4 = 0;
	}
}
//===============================================================================
//*****************************TC0分频比设置函数*********************************
//TC0分频比设置
//输入		tc0Predivision					//TC0预分频比选择参数
//输入		tc0Division						//TC0预分频后分频比选择参数
//===============================================================================
void TC0_SETPREDIVISION(enum TC0_PREDIVISION tc0Predivision,enum TC0_DIVISION tc0Division)
{
	T0CR &= ~(0x07 << 0);
	T0CR |= tc0Predivision;
	T0CR2 &= ~(0x07 << 0);
	T0CR2 |= tc0Division;
}
//===============================================================================
//*****************************TC0计数设置函数***********************************
//TC0计数设置
//输入		tc0Tc0ch						//TC0计数器高位选择参数
//输入		tc0Tc0cl						//TC0计数器低位选择参数
//===============================================================================
void TC0_SETTC0C(enum TC0_TC0CH tc0Tc0ch,enum TC0_TC0CL tc0Tc0cl)
{
	TC0CH &= ~(0xFF << 0);
	TC0CH |= (tc0Tc0ch << 0);
	TC0CL &= ~(0xFF << 0);
	TC0CL |= (tc0Tc0cl << 0);
}
//===============================================================================
//*********************************TC0处理程序***********************************
//TC0处理:主循环TC0中断标志置1(10ms)串口打印10ms
//===============================================================================
void TC0_Work(void)
{
	if(b_TC0_Flag == 1)
	{
		b_TC0_Flag = 0;
		printf("TC0_Time = %s\n","10ms");
	}	
}
//===============================================================================
//********************************TC0中断处理函数********************************
//定时器TC0每计数10ms，进一次中断，标志位置高
//===============================================================================
void TC0_Interrupt (void)				
{
	if(TC0IF == 1)
	{				
		TC0IF = 0;	
		b_TC0_Flag = 1;	
	}
}

/*********************************END OF FILE************************************/