//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "TC1.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
bit	b_TC1_Flag;								//TC1进入中断后标志位置1
//===============================================================================
//********************************TC1初始化**************************************
//TC1初始化:TC1设置递增模式,高频系统时钟,预分频比设置1:64,TC1CL、TC1CH设置为0
//TC1PRH设置为97，TC1PRL设置为167
//===============================================================================
void TC1_INIT(void)
{
	/* TC1模式设置,递增模式 */
	TC1_SETMODE(TC1_MODE_Incresing);
	/* TC1时钟源设置,高频系统时钟 */
	TC1_SETCLOCK(TC1_CLOCK_Fosch);
	/* TC1预分频比设置,预分频比1:64 */
	TC1_SETPREDIVISION(TC1_PREDIVISION_64);
	/* TC1:计数=[TC1PRH_DATA:TC1PRL_DATA]-[TC1CH_DATA:TC1CL_DATA] */
	/* TC1C设置，[TC1CH_DATA:TC1CL_DATA]=0x0000 */
	TC1_SETTC1C(TC1_TC1CH_0 , TC1_TC1CL_0);
	/* TC1PR设置，[TC1PRH_DATA:TC1PRL_DATA]=0x61A7 */
	TC1_SETTC1PR(TC1_TC1PRH_97 , TC1_TC1PRL_167);	//t =计数/（时钟/分频）
	/* TC1模块使能位,使能TC1 */
	TC1EN = ENABLE;
	/*中断设置*/
	TC1IE = ENABLE;
	TC1IF = DISABLE;
	/* 使用TC1中断时必须要保持INTPTC1全为0 */
	INTPTC1 &= ~(0xFF << 0);
	GIEH = ENABLE;
}
//===============================================================================
//*****************************TC1模式设置函数***********************************
//TC1模式设置
//输入		tc1Mode							//TC1模式选择参数
//===============================================================================
void TC1_SETMODE(enum TC1_MODE tc1Mode)
{
	T1CR &= ~(0x03 << 5);
	T1CR |= tc1Mode;
}
//===============================================================================
//****************************TC1时钟源设置函数**********************************
//TC1时钟源设置
//输入		tc1Clock						//TC1时钟源选择参数
//===============================================================================
void TC1_SETCLOCK(enum TC1_CLOCK tc1Clock)
{
	T1CR &= ~(0x03 << 3);
	T1CR |= tc1Clock;
	if(tc1Clock == TC1_CLOCK_T1CKI)
	{
		ANSA5 = 0;
		OEA5 = 0;
	}
}
//===============================================================================
//***************************TC1预分频比设置函数*********************************
//TC1预分频比设置
//输入		tc1Predivision					//TC1预分频选择参数
//===============================================================================
void TC1_SETPREDIVISION(enum TC1_PREDIVISION tc1Predivision)
{
	T1CR &= ~(0x07 << 0);
	T1CR |= tc1Predivision;
}
//===============================================================================
//***************************TC1计数TC1C设置函数*********************************
//TC1计数TC1C设置
//输入		tc1Tc1ch						//TC1计数器高位选择参数
//输入		tc1Tc1cl						//TC1计数器低位选择参数
//===============================================================================
void TC1_SETTC1C(enum TC1_TC1CH tc1Tc1ch,enum TC1_TC1CL tc1Tc1cl)
{
	TC1CH &= ~(0xFF << 0);
	TC1CH |= (tc1Tc1ch << 0);
	TC1CL &= ~(0xFF << 0);
	TC1CL |= (tc1Tc1cl << 0);
}
//===============================================================================
//**************************TC1计数TC1PR设置函数*********************************
//TC1计数TC1PR设置
//输入		tc1Tc1prh						//TC1周期寄存器高位选择参数
//输入		tc1Tc1prl						//TC1周期寄存器低位选择参数
//===============================================================================
void TC1_SETTC1PR(enum TC1_TC1PRH tc1Tc1prh,enum TC1_TC1PRL tc1Tc1prl)
{
	TC1PRH &= ~(0xFF << 0);
	TC1PRH |= (tc1Tc1prh << 0);
	TC1PRL &= ~(0xFF << 0);
	TC1PRL |= (tc1Tc1prl << 0);
}
//===============================================================================
//*********************************TC1处理程序***********************************
//TC1处理:主循环TC1中断标志置1(100ms)串口打印100ms
//===============================================================================
void TC1_Work(void)
{
	if(b_TC1_Flag == 1)
	{
		b_TC1_Flag = 0;
		printf("TC1_Time = %s\n","100ms");
	}	
}
//===============================================================================
//********************************TC1中断处理函数********************************
//定时器TC1每计数100ms，进一次中断，标志位置高
//===============================================================================
void TC1_Interrupt (void)				
{
	if(TC1IF == 1)
	{				
		TC1IF = 0;	
		b_TC1_Flag = 1;	
	}
}

/*********************************END OF FILE************************************/