//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "TC0.h"
#include "TC2G.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
bit	b_TC2G_Flag;							//TC2G进入中断后标志位置1
//===============================================================================
//********************************TC2G初始化*************************************
//TC2G初始化:高频系统时钟,预分频比设置1:16,门控选择TC0溢出周期，上升沿到上升沿
//TC2CH设置为0,TC2CL设置为0,TC2PRH设置为0,TC2PRL设置为0
//===============================================================================
void TC2G_INIT(void)
{
	/* TC2时钟源设置,高频系统时钟 */
	TC2_SETCLOCK(TC2_CLOCK_Fosch);
	/* TC2预分频比设置,预分频比1:16 */
	TC2_SETPREDIVISION(TC2_PREDIVISION_16);
	/* TC2GCR门控设置,TC2门控选择TC0溢出周期,上升沿到上升沿 */
	/* 选择TC0溢出周期（模式只选择上升沿到上升沿模式） */
	TC2_GATED(TC2GCR_GATEDSOURCE_TC0 , TC2GCR_MODE_UP_UP);
	/* TC2:计数=[TC2PRH_DATA:TC2PRL_DATA]-[TC2CH_DATA:TC2CL_DATA] */
	/* TC2C设置，[TC2CH_DATA:TC2CL_DATA]=0X0000 */
	TC2_SETTC2C(TC2_TC2CH_0 , TC2_TC2CL_0);
	/* TC2PR设置，[TC2PRH_DATA:TC2PRL_DATA]=0X0000 */
	TC2_SETTC2PR(TC2_TC2PRH_0 , TC2_TC2PRL_0);	//t =计数/（时钟/分频）
	/* 使能TC2及TC2门控 */
	TC2EN = ENABLE;
	TC2GEN = ENABLE;
	/* TC2GCR启动门控控制,启动门控 */
	TC2GCR_SETTC2GO(TC2GO_ENABLE);
	/* 中断配置 */
	TC2GIF = DISABLE;				
	TC2GIE = ENABLE;
	TC2GIP = ENABLE;
	GIEL = ENABLE;
}
//===============================================================================
//*****************************TC2时钟源设置函数*********************************
//TC2时钟源设置
//输入		tc2Clock						//TC2时钟源选择参数
//===============================================================================
void TC2_SETCLOCK(enum TC2_CLOCK tc2Clock)
{
	T2CR &= ~(0x03 << 3);
	T2CR |= tc2Clock;
	if(tc2Clock == TC2_CLOCK_T2CKI)
	{
		ANSA6 = 0;
		OEA6 = 0;
	}
}
//===============================================================================
//****************************TC2预分频比设置函数********************************
//TC2预分频比设置
//输入		tc2Predivision					//TC2预分频比选择参数
//===============================================================================
void TC2_SETPREDIVISION(enum TC2_PREDIVISION tc2Predivision)
{
	T2CR &= ~(0x07 << 0);
	T2CR |= tc2Predivision;
}
//===============================================================================
//****************************TC2GCR门控设置函数*********************************
//TC2GCR门控设置
//输入		tc2gcrGatedsource				//TC2门控源选择参数
//输入		tc2gcrMode						//TC2门控模式选择参数
//===============================================================================
void TC2_GATED(enum TC2GCR_GATEDSOURCE tc2gcrGatedsource,enum TC2GCR_MODE tc2gcrMode)
{
	TC2GCR &= ~0x0F;
	if(tc2gcrGatedsource == TC2GCR_GATEDSOURCE_TC0)
	{
		TC2GCR |= (0x07 << 1);
		/* TC0模式设置,8位模式 */
		TC0_SETMODE(TC0_MODE_8);
		/* TC0内部高频时钟选择设置，16M(24M禁用) */
		TC0_SETOSCS(TC0_OSCS_16M);
		/* TC0时钟源设置,高频系统时钟 */
		TC0_SETCLOCK(TC0_CLOCK_Fosch);
		/* TC0预分频比设置,预分频比1:128,分频比1:5 */
		TC0_SETPREDIVISION(TC0_PREDIVISION_128 , TC0_DIVISION_5);
		/* 计数器设置  t =计数/（时钟/分频）*/
		/* TC0:8位模式 计数=TC0CL_DATA-TC0CH_DATA */
		/* TC0:16位模式 计数=0xFFFF-[TC0CH_DATA:TC0CL_DATA] */
		TC0_SETTC0C(TC0_TC0CH_0 , TC0_TC0CL_249);										
		/*TC0开关设置,使能TC0*/
		TC0EN = ENABLE;	
	}
	else
	{
		TC2GCR |= (tc2gcrGatedsource | tc2gcrMode);
		if(tc2gcrGatedsource == TC2GCR_GATEDSOURCE_T2G0)
		{
			ANSA7 = 0;
			OEA7 = 0;
		}
		else if(tc2gcrGatedsource == TC2GCR_GATEDSOURCE_T2G1)
		{
			ANSB0 = 0;
			OEB0 = 0;
		}
		else if(tc2gcrGatedsource == TC2GCR_GATEDSOURCE_T2G2)
		{
			ANSB1 = 0;
			OEB1 = 0;
		}
	}
}
//===============================================================================
//**************************TC2GCR启动门控控制函数*******************************
//TC2GCR启动门控控制
//输入		tc2gcrTc2go						//TC2GCR启动门控控制选择参数
//===============================================================================
void TC2GCR_SETTC2GO(enum TC2GCR_TC2GO tc2gcrTc2go)
{
	TC2GCR &= ~(0x01 << 6);
	TC2GCR |= tc2gcrTc2go;
}
//===============================================================================
//****************************TC2计数TC2C设置函数********************************
//TC2计数TC2C设置
//输入		tc2Tc2ch						//TC2计数器高位选择参数
//输入		tc2Tc2cl						//TC2计数器低位选择参数
//===============================================================================
void TC2_SETTC2C(enum TC2_TC2CH tc2Tc2ch,enum TC2_TC2CL tc2Tc2cl)
{
	TC2CH &= ~(0xFF << 0);
	TC2CH |= (tc2Tc2ch << 0);
	TC2CL &= ~(0xFF << 0);
	TC2CL |= (tc2Tc2cl << 0);
}
//===============================================================================
//***************************TC2计数TC2PR设置函数********************************
//TC2计数TC2PR设置
//输入		tc2Tc2prh						//TC2周期寄存器高位选择参数
//输入		tc2Tc2prl						//TC2周期寄存器低位选择参数
//===============================================================================
void TC2_SETTC2PR(enum TC2_TC2PRH tc2Tc2prh,enum TC2_TC2PRL tc2Tc2prl)
{
	TC2PRH &= ~(0xFF << 0);
	TC2PRH |= (tc2Tc2prh << 0);
	TC2PRL &= ~(0xFF << 0);
	TC2PRL |= (tc2Tc2prl << 0);
}
//===============================================================================
//********************************TC2G处理程序***********************************
//TC2G处理:主循环TC2G中断标志置1(20ms)串口打印20ms
//===============================================================================
void TC2G_Work(void)
{
	if(b_TC2G_Flag == 1)
	{
		b_TC2G_Flag = 0;
		printf("TC2GCR_Time = %s\n","20ms");
	}
}
//===============================================================================
//********************************TC2G中断处理函数*******************************
//定时器TC2G每触发一次，进一次中断，标志位置高
//===============================================================================
void TC2G_Interrupt (void)				
{
	if(TC2GIF == 1)
	{					
		TC2GIF = 0;
		b_TC2G_Flag = 1;
		TC2GO = 1;		
	}
}

/*********************************END OF FILE************************************/