//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "USART.h"
#include "stdio.h"
//===============================================================================
//**********************************定义变量*************************************
//用户可以自行看需求定义变量
//===============================================================================
#define	Fosc_Count				16000000//系统时钟设置
#define Bps_Count				38400	//Usart波特率设置
volatile u8  Usart_Receive_Data;		//接收数据存入Usart_Receive_Data寄存器中
volatile u8  Receive_Data_Err;			//接错误数据放在Receive_Data_Err寄存器中
//===============================================================================
//********************************Usart初始化************************************
//TX初始化:TX选择IOA6,选择异步模式,数据长度选择8位数据,波特率选择38400
//TX初始化:RX选择IOA7,选择上升沿发送数据,数据长度选择8位数据
//===============================================================================
void Usart_INIT(void)
{
	/*串口复用口选择,TX选择IOA6、RX选择IOA7*/
	USART_SETMPUSART(TX_IOA6 , RX_IOA7);
	/*Usart的TX初始化（IOA6用作TX复用口，波特率为38400，发送数据为8位)*/
	/*TX发送寄存器空标志设置,正在发送数据，移位寄存器不空*/
	TX_SETTMCLR(TX_TMCLR_ING);
	/*同步模式设置,选择异步模式*/
	TX_SETSYNC(TX_SYNC_ASYNC);
	/*TX数据长度选择设置,8位数据*/
	TX_SETTX9(TX_TX9_8);
	/*同步发送/接受模式设置,Master*/
	TX_SETSLAVE(TX_SLAVE_Master);
	/* 波特率设置38400 */
	/* 波特率可选择:300、600、1200、2400、4800、9600、19200、38400、57600、115200*/
	Usart_Bps();
	/*Usart的RX初始化*/
	/*RX同步模式始终模式选择设置,上升沿发送数据*/
	RX_SETCKPS(RX_CKPS_UP);
	/*RX数据长度选择设置,8位数据*/
	RX_SETRX9(RX_RX9_8);
	/*同步接收开始设置,停止同步接收*/
	RX_SETSREN(RX_SREN_STOP);
	/*接收缓冲区溢出标志设置,接收缓冲区未发生溢出*/
	RX_SETRXOVF(RX_RXOVF_N);
	/*接受数据格式错设置,当前接收数据未发生格式错*/
	RX_SETFRER(RX_FRER_RIGHT);
	/*USART使能设置,使能USART发送\接收功能*/
	TXEN = ENABLE;
	RXEN = ENABLE;
	/*中断设置*/
	RX0IF = DISABLE;
	RX0IE = ENABLE;
	GIEH = ENABLE;
}
//===============================================================================
//****************************串口复用口设置函数*********************************
//串口复用口设置函数
//输入		TXMptx							//TX复用口选择参数
//输入		RXMprx							//RX复用口选择参数
//===============================================================================
void USART_SETMPUSART(enum MPTX_SELECT TXMptx,enum MPRX_SELECT RXMprx)
{
	u8 USART_IOData,USART_IOMP;
	USART_IOMP = TXMptx & 0x07;
	USART_IOData = (unsigned char)(0x01 << USART_IOMP);
	MPTX &= ~(0xFF << 0);
	if(TXMptx <= TX_IOA7)
	{
		OEA  |= USART_IOData;
		ANSA &= (unsigned char)~USART_IOData;
	}		
	else if(TXMptx <= TX_IOB7)
	{
		OEB  |= USART_IOData;
		ANSB &= (unsigned char)~USART_IOData;
		MPTX |= (0X01 << 4);
	}	
	else if(TXMptx <= TX_IOC7)
	{
		OEC  |= USART_IOData;
		ANSC &= (unsigned char)~USART_IOData;
		MPTX |= (0X02 << 4);
	}
	else if(TXMptx <= TX_IOD1)
	{
		OED  |= USART_IOData;
		ANSD &= (unsigned char)~USART_IOData;
		MPTX |= (0X03 << 4);
	}
	MPTX |= (unsigned char)(USART_IOMP << 0);

	USART_IOMP = RXMprx & 0x07;
	USART_IOData = (unsigned char)(0x01 << USART_IOMP);
	MPRX &= ~(0xFF << 0);
	if(RXMprx <= RX_IOA7)
	{
		OEA  &= (unsigned char)~USART_IOData;
		ANSA &= (unsigned char)~USART_IOData;
	}
	else if(RXMprx <= RX_IOB7)
	{
		OEB  &= (unsigned char)~USART_IOData;
		ANSB &= (unsigned char)~USART_IOData;
		MPRX |= (0X01 << 4);
	}
	else if(RXMprx <= RX_IOC7)
	{
		OEC  &= (unsigned char)~USART_IOData;
		ANSC &= (unsigned char)~USART_IOData;
		MPRX |= (0X02 << 4);
	}
	else if(RXMprx <= RX_IOD1)
	{
		OED  &= (unsigned char)~USART_IOData;
		MPRX |= (0X03 << 4);
	}
	MPRX |= (unsigned char)(USART_IOMP << 0);
}
//===============================================================================
//************************TX发送寄存器空标志设置函数*****************************
//TX发送寄存器空标志设置
//输入		TXTMCLR							//Usart模块TX发送寄存器空标志选择参数
//===============================================================================
void TX_SETTMCLR(enum TX_TMCLR TXTMCLR)
{
	TX0CR &= ~(0x01 << 6);
	TX0CR |= TXTMCLR;
}
//===============================================================================
//*****************************同步模式设置函数**********************************
//同步模式设置
//输入		TXSYNC							//Usart模块同步模式选择参数
//===============================================================================
void TX_SETSYNC(enum TX_SYNC TXSYNC)
{
	TX0CR &= ~(0x01 << 5);
	TX0CR |= TXSYNC;
}
//===============================================================================
//**************************TX数据长度选择设置函数*******************************
//TX数据长度选择设置
//输入		TXTX9							//Usart模块TX数据长度选择参数
//===============================================================================
void TX_SETTX9(enum TX_TX9 TXTX9)
{
	TX0CR &= ~(0x01 << 4);
	TX0CR |= TXTX9;
}
//===============================================================================
//*************************同步发送/接受模式设置函数*****************************
//同步发送/接受模式设置
//输入		TXSLAVE							//Usart模块同步发送/接受模式选择参数
//===============================================================================
void TX_SETSLAVE(enum TX_SLAVE TXSLAVE)
{
	TX0CR &= ~(0x01 << 3);
	TX0CR |= TXSLAVE;
}
//===============================================================================
//***********************RX同步模式始终模式选择设置函数**************************
//RX同步模式始终模式选择设置
//输入		RXCKPS							//Usart模块RX同步模式始终模式选择参数
//===============================================================================
void RX_SETCKPS(enum RX_CKPS RXCKPS)
{
	RX0CR &= ~(0x01 << 6);
	RX0CR |= RXCKPS;
}
//===============================================================================
//**************************RX数据长度选择设置函数*******************************
//RX数据长度选择设置
//输入		RXRX9							//Usart模块RX数据长度选择参数
//===============================================================================
void RX_SETRX9(enum RX_RX9 RXRX9)
{
	RX0CR &= ~(0x01 << 4);
	RX0CR |= RXRX9;
}
//===============================================================================
//***************************同步接收开始设置函数********************************
//同步接收开始设置
//输入		RXSREN							//Usart模块同步接收开始选择参数
//===============================================================================
void RX_SETSREN(enum RX_SREN RXSREN)
{
	RX0CR &= ~(0x01 << 3);
	RX0CR |= RXSREN;
}
//===============================================================================
//************************接收缓冲区溢出标志设置函数*****************************
//接收缓冲区溢出标志设置
//输入		RXRXOVF							//Usart模块接收缓冲区溢出标志选择参数
//===============================================================================
void RX_SETRXOVF(enum RX_RXOVF RXRXOVF)
{
	RX0CR &= ~(0x01 << 2);
	RX0CR |= RXRXOVF;
}
//===============================================================================
//***************************接受数据格式错设置**********************************
//接受数据格式错设置
//输入		RXFRER							//Usart模块接受数据格式错选择参数
//===============================================================================
void RX_SETFRER(enum RX_FRER RXFRER)
{
	RX0CR &= ~(0x01 << 1);
	RX0CR |= RXFRER;
}
//===============================================================================
//******************************波特率设置函数***********************************
//波特率设置
//输入		Bps_Count						//Usart模块波特率选择参数
//TX0CR |= (0x00)		1:4分频比			波特率19200、38400、57600、115200
//TX0CR |= (0x02)		1:16分频比			波特率4800、9600
//TX0CR |= (0x04)		1:64分频比			波特率1200、2400
//TX0CR |= (0x06)		1:256分频比			波特率300、600
//===============================================================================
void Usart_Bps(void)
{
	TX0CR |= (0x00);
	BRGD0L = (u8)((u16)((float)Fosc_Count/4/Bps_Count+0.5)-1);
}
//===============================================================================
//*********************************串口打印函数**********************************
//串口打印程序，打印内容可通过修改Putchar_Data进行改变
//===============================================================================
void putchar(u8 Putchar_Data)
{
	TX0REG = Putchar_Data;
	while(!TMCLR);
}
//===============================================================================
//*******************************串口发送数据函数********************************
//串口发送数据程序，发送的数据内容可通过修改Usart_Data进行改变
//===============================================================================
void Usart_Send_Byte(u8 Usart_Data)
{
	TX0REG = Usart_Data;
	while(!TMCLR);
}
//===============================================================================
//*********************************Usart处理*************************************
//Usart处理:串口选择Hex,发送数据0x50
//串口选择ASCII,数组数据发送为P,打印内容为http://www.masses-chip.com
//===============================================================================
void Usart_Work (void)
{
	Delay_1ms(100);
	/*串口发送一个数据0x50*/
	Usart_Send_Byte(0x50);
	/*串口打印http://www.masses-chip.com*/
	printf(":%s\n","http://www.masses-chip.com/");
}
//===============================================================================
//*********************************Usart中断处理函数*****************************
//Usart_Receive中断处理函数
//将接收到的数据放入Usart_Receive_Data中
//===============================================================================
void Usart_Interrupt (void)
{
	if(RX0IF == 1)
	{
		if(FRER == 0)
		{
			Usart_Receive_Data = RX0REG;
		}
		else
		{
			Receive_Data_Err = RX0REG;
		}
	}
}

/*********************************END OF FILE************************************/