#ifndef __USART_H__
#define __USART_H__

#include "zc.h"
#include "MASSESCHIP_DEFINE.H"

#define ENABLE							1
#define DISABLE							0
//================================================================================
/* RX端口复用 */
enum MPTX_SELECT
{
/* 选用IOD端口时只有IOD0,及IOD1可用 */
	TX_IOA0 = 0,TX_IOA1,TX_IOA2,TX_IOA3,TX_IOA4,TX_IOA5,TX_IOA6,TX_IOA7,
	TX_IOB0,TX_IOB1,TX_IOB2,TX_IOB3,TX_IOB4,TX_IOB5,TX_IOB6,TX_IOB7,
	TX_IOC0,TX_IOC1,TX_IOC2,TX_IOC3,TX_IOC4,TX_IOC5,TX_IOC6,TX_IOC7,
	TX_IOD0,TX_IOD1,
};
/* TX端口复用 */
enum MPRX_SELECT
{
/* 选用IOD端口时只有IOD0,及IOD1可用 */
	RX_IOA0 = 0,RX_IOA1,RX_IOA2,RX_IOA3,RX_IOA4,RX_IOA5,RX_IOA6,RX_IOA7,
	RX_IOB0,RX_IOB1,RX_IOB2,RX_IOB3,RX_IOB4,RX_IOB5,RX_IOB6,RX_IOB7,
	RX_IOC0,RX_IOC1,RX_IOC2,RX_IOC3,RX_IOC4,RX_IOC5,RX_IOC6,RX_IOC7,
	RX_IOD0,RX_IOD1,
};
/* TX发送寄存器空标志 */
enum TX_TMCLR
{
	TX_TMCLR_ING = 0x00,//正在发送数据，移位寄存器不空
	TX_TMCLR_END = 0x40,//数据已发送，移位寄存器空
};
/* 同步模式 */
enum TX_SYNC
{
	TX_SYNC_ASYNC = 0x00,//选择异步模式
	TX_SYNC_SYNC = 0x20,//选择同步模式
};
/* TX数据长度选择 */
enum TX_TX9
{
	TX_TX9_8 = 0x00,//8位数据
	TX_TX9_9 = 0x10,//9位数据
};
/* 同步发送/接受模式 */
enum TX_SLAVE
{
	TX_SLAVE_Master = 0x00,//Master
	TX_SLAVE_Slave = 0x08,//Slave
};
/* 波特率时钟源分频比 */
enum TX_SPD
{
	TX_SPD_4 = 0x00,//波特率分频比1:4
	TX_SPD_16 = 0x02,//波特率分频比1:16
	TX_SPD_64 = 0x04,//波特率分频比1:64
	TX_SPD_256 = 0x06,//波特率分频比1:256
};
/* RX同步模式始终模式选择 */
enum RX_CKPS
{
	RX_CKPS_UP = 0x00,//上升沿发送数据
	RX_CKPS_DOWM = 0x40,//下降沿发送数据
};
/* RX数据长度选择 */
enum RX_RX9
{
	RX_RX9_8 = 0x00,//8位数据
	RX_RX9_9 = 0x10,//9位数据
};
/* 同步接收开始 */
enum RX_SREN
{
	RX_SREN_STOP = 0x00,//停止同步接收
	RX_SREN_START = 0x08,//开始同步接收，单字节接收模式下接收完一个字节自动清零
};
/* 接收缓冲区溢出标志 */
enum RX_RXOVF
{
	RX_RXOVF_N = 0x00,//接收缓冲区未发生溢出
	RX_RXOVF_Y = 0x04,//接收缓冲区溢出，读缓冲区自动清零
};
/* 接受数据格式错 */
enum RX_FRER
{
	RX_FRER_RIGHT = 0x00,//当前接收数据未发生格式错
	RX_FRER_ERR = 0x02,//当前接收数据格式错(未收到停止位)
};
//=================================串口函数声明===========================================
void SYSTEM_INIT(void);//系统初始化
void Delay_1ms(u16 Delay_Count);//延时
void USART_SETMPUSART(enum MPTX_SELECT TXMptx,enum MPRX_SELECT RXMprx);//串口复用口选择
void TX_SETTMCLR(enum TX_TMCLR TXTMCLR);//TX发送寄存器空标志设置
void TX_SETSYNC(enum TX_SYNC TXSYNC);//同步模式设置
void TX_SETTX9(enum TX_TX9 TXTX9);//TX数据长度选择设置
void TX_SETSLAVE(enum TX_SLAVE TXSLAVE);//同步发送/接受模式设置
void RX_SETCKPS(enum RX_CKPS RXCKPS);//RX同步模式始终模式选择设置
void RX_SETRX9(enum RX_RX9 RXRX9);//RX数据长度选择设置
void RX_SETSREN(enum RX_SREN RXSREN);//同步接收开始设置
void RX_SETRXOVF(enum RX_RXOVF RXRXOVF);//接收缓冲区溢出标志设置
void RX_SETFRER(enum RX_FRER RXFRER);//接受数据格式错设置
void Usart_Bps(void);//波特率设置
void putchar(u8 Putchar_Data);//串口打印
void Usart_Send_Byte(u8 UsartData);//串口发送一个数据
void Usart_Work(void);//串口处理程序
void Usart_INIT(void);//串口初始化
void Usart_Interrupt(void);//串口中断处理程序

#endif